% Auto-generated chapter 86 for bukhari
% Hadiths in this chapter: 81

\hadithdefcmd{bukhari}{6772}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهْوَ مُؤْمِنٌ، وَلاَ يَشْرَبُ الْخَمْرَ حِينَ يَشْرَبُ وَهْوَ مُؤْمِنٌ، وَلاَ يَسْرِقُ حِينَ يَسْرِقُ وَهْوَ مُؤْمِنٌ، وَلاَ يَنْتَهِبُ نُهْبَةً يَرْفَعُ النَّاسُ إِلَيْهِ فِيهَا أَبْصَارَهُمْ وَهْوَ مُؤْمِنٌ ‏"‏‏.‏ وَعَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ، إِلاَّ النُّهْبَةَ‏.‏\hadithno{6772}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When an adulterer commits illegal sexual intercourse, then he is not a believer at the time he is doing it; and when somebody drinks an alcoholic drink, then he is not believer at the time of drinking, and when a thief steals, he is not a believer at the time when he is stealing; and when a robber robs and the people look at him, then he is not a believer at the time of doing it." Abu Huraira in another narration, narrated the same from the Prophet (ﷺ) with the exclusion of robbery}}
\hadithdefcmd{bukhari}{6773}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ح حَدَّثَنَا آدَمُ حَدَّثَنَا شُعْبَةُ حَدَّثَنَا قَتَادَةُ عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم ضَرَبَ فِي الْخَمْرِ بِالْجَرِيدِ وَالنِّعَالِ، وَجَلَدَ أَبُو بَكْرٍ أَرْبَعِينَ‏.‏\hadithno{6773}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) beat a drunk with palm-leaf stalks and shoes. And Abu Bakr gave (such a sinner) forty lashes}}
\hadithdefcmd{bukhari}{6774}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ جِيءَ بِالنُّعَيْمَانِ أَوْ بِابْنِ النُّعَيْمَانِ شَارِبًا، فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم مَنْ كَانَ بِالْبَيْتِ أَنْ يَضْرِبُوهُ‏.‏ قَالَ فَضَرَبُوهُ، فَكُنْتُ أَنَا فِيمَنْ ضَرَبَهُ بِالنِّعَالِ‏.‏\hadithno{6774}\hadithtrans{Narrated `Uqba bin Al-Harith:An-Nu`man or the son of An-Nu`man was brought to the Prophet (ﷺ) on a charge of drunkenness. So the Prophet ordered all the men present in the house, to beat him. So all of them beat him, and I was also one of them who beat him with shoes}}
\hadithdefcmd{bukhari}{6775}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِنُعَيْمَانَ أَوْ بِابْنِ نُعَيْمَانَ وَهْوَ سَكْرَانُ فَشَقَّ عَلَيْهِ، وَأَمَرَ مَنْ فِي الْبَيْتِ أَنْ يَضْرِبُوهُ، فَضَرَبُوهُ بِالْجَرِيدِ وَالنِّعَالِ، وَكُنْتُ فِيمَنْ ضَرَبَهُ‏.‏\hadithno{6775}\hadithtrans{Narrated' `Uqba bin Al-Harith:An-Nu`man or the son of An-Nu`man was brought to the Prophet (ﷺ) in a state of intoxication. The Prophet felt it hard (was angry) and ordered all those who were present in the house, to beat him. And they beat him, using palm-leaf stalks and shoes, and I was among those who beat him}}
\hadithdefcmd{bukhari}{6776}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، قَالَ جَلَدَ النَّبِيُّ صلى الله عليه وسلم فِي الْخَمْرِ بِالْجَرِيدِ وَالنِّعَالِ، وَجَلَدَ أَبُو بَكْرٍ أَرْبَعِينَ‏.‏\hadithno{6776}\hadithtrans{Narrated Anas:The Prophet (ﷺ) lashed a drunk with dateleaf stalks and shoes. And Abu Bakr gave a drunk forty lashes}}
\hadithdefcmd{bukhari}{6777}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو ضَمْرَةَ، أَنَسٌ عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِرَجُلٍ قَدْ شَرِبَ قَالَ ‏"‏ اضْرِبُوهُ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ فَمِنَّا الضَّارِبُ بِيَدِهِ، وَالضَّارِبُ بِنَعْلِهِ، وَالضَّارِبُ بِثَوْبِهِ، فَلَمَّا انْصَرَفَ قَالَ بَعْضُ الْقَوْمِ أَخْزَاكَ اللَّهُ‏.‏ قَالَ ‏"‏ لاَ تَقُولُوا هَكَذَا لاَ تُعِينُوا عَلَيْهِ الشَّيْطَانَ ‏"‏‏.‏\hadithno{6777}\hadithtrans{Narrated Abu Salama:Abu Huraira said, "A man who drank wine was brought to the Prophet. The Prophet (ﷺ) said, 'Beat him!" Abu Huraira added, "So some of us beat him with our hands, and some with their shoes, and some with their garments (by twisting it) like a lash, and then when we finished, someone said to him, 'May Allah disgrace you!' On that the Prophet (ﷺ) said, 'Do not say so, for you are helping Satan to overpower him}}
\hadithdefcmd{bukhari}{6778}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو حَصِينٍ، سَمِعْتُ عُمَيْرَ بْنَ سَعِيدٍ النَّخَعِيَّ، قَالَ سَمِعْتُ عَلِيَّ بْنَ أَبِي طَالِبٍ ـ رضى الله عنه ـ قَالَ مَا كُنْتُ لأُقِيمَ حَدًّا عَلَى أَحَدٍ فَيَمُوتَ، فَأَجِدَ فِي نَفْسِي، إِلاَّ صَاحِبَ الْخَمْرِ، فَإِنَّهُ لَوْ مَاتَ وَدَيْتُهُ، وَذَلِكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَسُنَّهُ‏.‏\hadithno{6778}\hadithtrans{Narrated `Ali bin Abi Talib:I would not feel sorry for one who dies because of receiving a legal punishment, except the drunk, for if he should die (when being punished), I would give blood money to his family because no fixed punishment has been ordered by Allah's Messenger (ﷺ) for the drunk}}
\hadithdefcmd{bukhari}{6779}{حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، عَنِ الْجُعَيْدِ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ كُنَّا نُؤْتَى بِالشَّارِبِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِمْرَةِ أَبِي بَكْرٍ وَصَدْرًا مِنْ خِلاَفَةِ عُمَرَ، فَنَقُومُ إِلَيْهِ بِأَيْدِينَا وَنِعَالِنَا وَأَرْدِيَتِنَا، حَتَّى كَانَ آخِرُ إِمْرَةِ عُمَرَ، فَجَلَدَ أَرْبَعِينَ، حَتَّى إِذَا عَتَوْا وَفَسَقُوا جَلَدَ ثَمَانِينَ‏.‏\hadithno{6779}\hadithtrans{Narrated As-Sa'ib bin Yazid:We used to strike the drunks with our hands, shoes, clothes (by twisting it into the shape of lashes) during the lifetime of the Prophet, Abu Bakr and the early part of `Umar's caliphate. But during the last period of `Umar's caliphate, he used to give the drunk forty lashes; and when drunks became mischievous and disobedient, he used to scourge them eighty lashes}}
\hadithdefcmd{bukhari}{6780}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي خَالِدُ بْنُ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ رَجُلاً، عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم كَانَ اسْمُهُ عَبْدَ اللَّهِ، وَكَانَ يُلَقَّبُ حِمَارًا، وَكَانَ يُضْحِكُ رَسُولَ اللَّهِ صلى الله عليه وسلم، وَكَانَ النَّبِيُّ صلى الله عليه وسلم قَدْ جَلَدَهُ فِي الشَّرَابِ، فَأُتِيَ بِهِ يَوْمًا فَأَمَرَ بِهِ فَجُلِدَ، فَقَالَ رَجُلٌ مِنَ الْقَوْمِ اللَّهُمَّ الْعَنْهُ مَا أَكْثَرَ مَا يُؤْتَى بِهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَلْعَنُوهُ، فَوَاللَّهِ مَا عَلِمْتُ أَنَّهُ يُحِبُّ اللَّهَ وَرَسُولَهُ ‏"‏‏.‏\hadithno{6780}\hadithtrans{Narrated `Umar bin Al-Khattab:During the lifetime of the Prophet (ﷺ) there was a man called `Abdullah whose nickname was Donkey, and he used to make Allah's Messenger (ﷺ) laugh. The Prophet (ﷺ) lashed him because of drinking (alcohol). And one-day he was brought to the Prophet (ﷺ) on the same charge and was lashed. On that, a man among the people said, "O Allah, curse him ! How frequently he has been brought (to the Prophet (ﷺ) on such a charge)!" The Prophet (ﷺ) said, "Do not curse him, for by Allah, I know for he loves Allah and His Apostle}}
\hadithdefcmd{bukhari}{6781}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنَا ابْنُ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِسَكْرَانَ، فَأَمَرَ بِضَرْبِهِ، فَمِنَّا مَنْ يَضْرِبُهُ بِيَدِهِ، وَمِنَّا مَنْ يَضْرِبُهُ بِنَعْلِهِ، وَمِنَّا مَنْ يَضْرِبُهُ بِثَوْبِهِ، فَلَمَّا انْصَرَفَ قَالَ رَجُلٌ مَالَهُ أَخْزَاهُ اللَّهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَكُونُوا عَوْنَ الشَّيْطَانِ عَلَى أَخِيكُمْ ‏"‏‏.‏\hadithno{6781}\hadithtrans{Narrated Abu Huraira:A drunk was brought to the Prophet (ﷺ) and he ordered him to be beaten (lashed). Some of us beat him with our hands, and some with their shoes, and some with their garments (twisted in the form of a lash). When that drunk had left, a man said, "What is wrong with him? May Allah disgrace him!" Allah's Messenger (ﷺ) said, "Do not help Satan against your (Muslim) brother}}
\hadithdefcmd{bukhari}{6782}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، حَدَّثَنَا فُضَيْلُ بْنُ غَزْوَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهْوَ مُؤْمِنٌ، وَلاَ يَسْرِقُ حِينَ يَسْرِقُ وَهْوَ مُؤْمِنٌ ‏"‏‏.‏\hadithno{6782}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "When (a person) an adulterer commits illegal sexual intercourse then he is not a believer at the time he is doing it; and when somebody steals, then he is not a believer at the time he is stealing}}
\hadithdefcmd{bukhari}{6783}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنِي أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ السَّارِقَ، يَسْرِقُ الْبَيْضَةَ فَتُقْطَعُ يَدُهُ، وَيَسْرِقُ الْحَبْلَ فَتُقْطَعُ يَدُهُ ‏"‏‏.‏ قَالَ الأَعْمَشُ كَانُوا يَرَوْنَ أَنَّهُ بَيْضُ الْحَدِيدِ، وَالْحَبْلُ كَانُوا يَرَوْنَ أَنَّهُ مِنْهَا مَا يَسْوَى دَرَاهِمَ‏.‏\hadithno{6783}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah curses a man who steals an egg and gets his hand cut off, or steals a rope and gets his hands cut off." Al-A`mash said, "People used to interpret the Baida as an iron helmet, and they used to think that the rope may cost a few dirhams}}
\hadithdefcmd{bukhari}{6784}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ ـ رضى الله عنه ـ قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فِي مَجْلِسٍ فَقَالَ ‏"‏ بَايِعُونِي عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَسْرِقُوا، وَلاَ تَزْنُوا ‏"‏‏.‏ وَقَرَأَ هَذِهِ الآيَةَ كُلَّهَا ‏"‏ فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَعُوقِبَ بِهِ، فَهْوَ كَفَّارَتُهُ، وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا، فَسَتَرَهُ اللَّهُ عَلَيْهِ، إِنْ شَاءَ غَفَرَ لَهُ، وَإِنْ شَاءَ عَذَّبَهُ ‏"‏‏.‏\hadithno{6784}\hadithtrans{Narrated 'Ubada bin As-Samit:We were with the Prophet (ﷺ) in a gathering and he said, 'Swear allegiance to me that you will not worship anything besides Allah, Will not steal, and will not commit illegal sexual intercourse." And then (the Prophet) recited the whole Verse (i.e. 60:12). The Prophet (ﷺ) added, 'And whoever among you fulfills his pledge, his reward is with Allah; and whoever commits something of such sins and receives the legal punishment for it, that will be considered as the expiation for that sin, and whoever commits something of such sins and Allah screens him, it is up to Allah whether to excuse or punish him}}
\hadithdefcmd{bukhari}{6785}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدٍ، عَنْ وَاقِدِ بْنِ مُحَمَّدٍ، سَمِعْتُ أَبِي قَالَ عَبْدُ اللَّهِ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ ‏"‏ أَلاَ أَىُّ شَهْرٍ تَعْلَمُونَهُ أَعْظَمُ حُرْمَةً ‏"‏‏.‏ قَالُوا أَلاَ شَهْرُنَا هَذَا‏.‏ قَالَ ‏"‏ أَلاَ أَىُّ بَلَدٍ تَعْلَمُونَهُ أَعْظَمُ حُرْمَةً ‏"‏‏.‏ قَالُوا أَلاَ بَلَدُنَا هَذَا‏.‏ قَالَ ‏"‏ أَلاَ أَىُّ يَوْمٍ تَعْلَمُونَهُ أَعْظَمُ حُرْمَةً ‏"‏‏.‏ قَالُوا أَلاَ يَوْمُنَا هَذَا‏.‏ قَالَ ‏"‏ فَإِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَدْ حَرَّمَ دِمَاءَكُمْ وَأَمْوَالَكُمْ وَأَعْرَاضَكُمْ، إِلاَّ بِحَقِّهَا، كَحُرْمَةِ يَوْمِكُمْ هَذَا، فِي بَلَدِكُمْ هَذَا، فِي شَهْرِكُمْ هَذَا، أَلاَ هَلْ بَلَّغْتُ ‏"‏‏.‏ ـ ثَلاَثًا كُلُّ ذَلِكَ يُجِيبُونَهُ أَلاَ نَعَمْ ـ قَالَ ‏"‏ وَيْحَكُمْ ـ أَوْ وَيْلَكُمْ ـ لاَ تَرْجِعُنَّ بَعْدِي كُفَّارًا، يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏‏.‏\hadithno{6785}\hadithtrans{Narrated `Abdullah:Allah's Apostle said in Hajjat-al-Wada`, "Which month (of the year) do you think is most sacred?" The people said, "This current month of ours (the month of Dhull-Hijja)." He said, "Which town (country) do you think is the most sacred?" They said, "This city of ours (Mecca)." He said, "Which day do you think is the most sacred?" The people said, "This day of ours." He then said, "Allah, the Blessed, the Supreme, has made your blood, your property and your honor as sacred as this day of yours in this town of yours, in this month of yours (and such protection cannot be slighted) except rightfully." He then said thrice, "Have I conveyed Allah's Message (to you)?" The people answered him each time saying, 'Yes." The Prophet (ﷺ) added, 'May Allah be merciful to you (or, woe on you)! Do not revert to disbelief after me by cutting the necks of each other}}
\hadithdefcmd{bukhari}{6786}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا خُيِّرَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ أَمْرَيْنِ إِلاَّ اخْتَارَ أَيْسَرَهُمَا، مَا لَمْ يَأْثَمْ، فَإِذَا كَانَ الإِثْمُ كَانَ أَبْعَدَهُمَا مِنْهُ، وَاللَّهِ مَا انْتَقَمَ لِنَفْسِهِ فِي شَىْءٍ يُؤْتَى إِلَيْهِ قَطُّ، حَتَّى تُنْتَهَكَ حُرُمَاتُ اللَّهِ، فَيَنْتَقِمُ لِلَّهِ‏.‏\hadithno{6786}\hadithtrans{Narrated Aisha:Whenever the Prophet (ﷺ) was given an option between two things, he used to select the easier of the tow as long as it was not sinful; but if it was sinful, he would remain far from it. By Allah, he never took revenge for himself concerning any matter that was presented to him, but when Allah's Limits were transgressed, he would take revenge for Allah's Sake}}
\hadithdefcmd{bukhari}{6787}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أُسَامَةَ، كَلَّمَ النَّبِيَّ صلى الله عليه وسلم فِي امْرَأَةٍ فَقَالَ ‏ "‏ إِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ أَنَّهُمْ كَانُوا يُقِيمُونَ الْحَدَّ عَلَى الْوَضِيعِ، وَيَتْرُكُونَ الشَّرِيفَ، وَالَّذِي نَفْسِي بِيَدِهِ لَوْ فَاطِمَةُ فَعَلَتْ ذَلِكَ لَقَطَعْتُ يَدَهَا ‏"‏‏.‏\hadithno{6787}\hadithtrans{Narrated `Aisha:Usama approached the Prophet (ﷺ) on behalf of a woman (who had committed theft). The Prophet (ﷺ) said, "The people before you were destroyed because they used to inflict the legal punishments on the poor and forgive the rich. By Him in Whose Hand my soul is! If Fatima (the daughter of the Prophet (ﷺ) ) did that (i.e. stole), I would cut off her hand}}
\hadithdefcmd{bukhari}{6788}{حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ قُرَيْشًا، أَهَمَّتْهُمُ الْمَرْأَةُ الْمَخْزُومِيَّةُ الَّتِي سَرَقَتْ فَقَالُوا مَنْ يُكَلِّمُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَكَلَّمَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏‏.‏ ثُمَّ قَامَ فَخَطَبَ قَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّمَا ضَلَّ مَنْ قَبْلَكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ الشَّرِيفُ تَرَكُوهُ، وَإِذَا سَرَقَ الضَّعِيفُ فِيهِمْ أَقَامُوا عَلَيْهِ الْحَدَّ، وَايْمُ اللَّهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعَ مُحَمَّدٌ يَدَهَا ‏"‏‏.‏\hadithno{6788}\hadithtrans{Narrated `Aisha:The Quraish people became very worried about the Makhzumiya lady who had committed theft. They said, "Nobody can speak (in favor of the lady) to Allah's Messenger (ﷺ) and nobody dares do that except Usama who is the favorite of Allah's Messenger (ﷺ). " When Usama spoke to Allah's Messenger (ﷺ) about that matter, Allah's Messenger (ﷺ) said, "Do you intercede (with me) to violate one of the legal punishment of Allah?" Then he got up and addressed the people, saying, "O people! The nations before you went astray because if a noble person committed theft, they used to leave him, but if a weak person among them committed theft, they used to inflict the legal punishment on him. By Allah, if Fatima, the daughter of Muhammad committed theft, Muhammad will cut off her hand}}
\hadithdefcmd{bukhari}{6789}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تُقْطَعُ الْيَدُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏‏.‏ تَابَعَهُ عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ وَابْنُ أَخِي الزُّهْرِيِّ وَمَعْمَرٌ عَنِ الزُّهْرِيِّ‏.‏\hadithno{6789}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "The hand should be cut off for stealing something that is worth a quarter of a Dinar or more}}
\hadithdefcmd{bukhari}{6790}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، عَنِ ابْنِ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَعَمْرَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي رُبُعِ دِينَارٍ ‏"‏‏.‏\hadithno{6790}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "The hand of a thief should be cut off for stealing a quarter of a Dinar}}
\hadithdefcmd{bukhari}{6791}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا الْحُسَيْنُ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الأَنْصَارِيِّ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، حَدَّثَتْهُ أَنَّ عَائِشَةَ ـ رضى الله عنها ـ حَدَّثَتْهُمْ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُقْطَعُ فِي رُبُعِ دِينَارٍ ‏"‏‏.‏\hadithno{6791}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "The hand should be cut off for stealing a quarter of a Dinar}}
\hadithdefcmd{bukhari}{6792}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، قَالَ أَخْبَرَتْنِي عَائِشَةُ، أَنَّ يَدَ السَّارِقِ، لَمْ تُقْطَعْ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ فِي ثَمَنِ مِجَنٍّ حَجَفَةٍ أَوْ تُرْسٍ‏.‏ حَدَّثَنَا عُثْمَانُ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، مِثْلَهُ‏.‏\hadithno{6792}\hadithtrans{Narrated `Aisha:The hand of a thief was not cut off during the lifetime of the Prophet (ﷺ) except for stealing something equal to a shield in value. A similar hadith is narrated from `Aisha through another chain}}
\hadithdefcmd{bukhari}{6793}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمْ تَكُنْ تُقْطَعُ يَدُ السَّارِقِ فِي أَدْنَى مِنْ حَجَفَةٍ أَوْ تُرْسٍ، كُلُّ وَاحِدٍ مِنْهُمَا ذُو ثَمَنٍ‏.‏ رَوَاهُ وَكِيعٌ وَابْنُ إِدْرِيسَ عَنْ هِشَامٍ عَنْ أَبِيهِ مُرْسَلاً‏.‏\hadithno{6793}\hadithtrans{Narrated `Aisha:A thief's hand was not cut off for stealing something cheaper than a Hajafa or a Turs (two kinds of shields), each of which was worth a (respectable) price}}
\hadithdefcmd{bukhari}{6794}{حَدَّثَنِي يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ هِشَامُ بْنُ عُرْوَةَ أَخْبَرَنَا عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمْ تُقْطَعْ يَدُ سَارِقٍ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فِي أَدْنَى مِنْ ثَمَنِ الْمِجَنِّ، تُرْسٍ أَوْ حَجَفَةٍ، وَكَانَ كُلُّ وَاحِدٍ مِنْهُمَا ذَا ثَمَنٍ‏.‏\hadithno{6794}\hadithtrans{Narrated `Aisha:A thief's hand was not cut off for stealing something worth less than the price of a shield, whether a Turs or Hajafa (two kinds of shields), each of which was worth a (respectable) price}}
\hadithdefcmd{bukhari}{6795}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطَعَ فِي مِجَنٍّ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ‏.‏ تَابَعَهُ مُحَمَّدُ بْنُ إِسْحَاقَ وَقَالَ اللَّيْثُ حَدَّثَنِي نَافِعٌ قِيمَتُهُ\hadithno{6795}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) cut off the hand of a thief for stealing a shield that was worth three Dirhams}}
\hadithdefcmd{bukhari}{6796}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَطَعَ النَّبِيُّ صلى الله عليه وسلم فِي مِجَنٍّ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ‏.‏\hadithno{6796}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) cut off the hand of a thief for stealing a shield that was worth three Dirhams}}
\hadithdefcmd{bukhari}{6797}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، قَالَ قَطَعَ النَّبِيُّ صلى الله عليه وسلم فِي مِجَنٍّ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ‏.‏\hadithno{6797}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) cut off the hand of a thief for stealing a shield that was worth three Dirhams}}
\hadithdefcmd{bukhari}{6798}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَطَعَ النَّبِيُّ صلى الله عليه وسلم يَدَ سَارِقٍ فِي مِجَنٍّ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ‏.‏ تَابَعَهُ مُحَمَّدُ بْنُ إِسْحَاقَ، وَقَالَ اللَّيْثُ حَدَّثَنِي نَافِعٌ ‏ "‏ قِيمَتُهُ ‏"‏‏.‏\hadithno{6798}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) cutoff the hand of a thief for stealing a shield that was worth three Dirhams}}
\hadithdefcmd{bukhari}{6799}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَنَ اللَّهُ السَّارِقَ، يَسْرِقُ الْبَيْضَةَ فَتُقْطَعُ يَدُهُ، وَيَسْرِقُ الْحَبْلَ فَتُقْطَعُ يَدُهُ ‏"‏‏.‏\hadithno{6799}\hadithtrans{Narrated Abu Huraira:Allah's Apostle said, "Allah curses the thief who steals an egg (or a helmet) for which his hand is to be cut off, or steals a rope, for which his hand is to be cut off}}
\hadithdefcmd{bukhari}{6800}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَطَعَ يَدَ امْرَأَةٍ‏.‏ قَالَتْ عَائِشَةُ وَكَانَتْ تَأْتِي بَعْدَ ذَلِكَ، فَأَرْفَعُ حَاجَتَهَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَتَابَتْ وَحَسُنَتْ تَوْبَتُهَا‏.‏\hadithno{6800}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) cut off the hand of a lady, and that lady used to come to me, and I used to convey her message to the Prophet (ﷺ) and she repented, and her repentance was sincere}}
\hadithdefcmd{bukhari}{6801}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْجُعْفِيُّ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ ـ رضى الله عنه ـ قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ، فَقَالَ ‏ "‏ أُبَايِعُكُمْ عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا، وَلاَ تَسْرِقُوا، وَلاَ تَقْتُلُوا أَوْلاَدَكُمْ، وَلاَ تَأْتُوا بِبُهْتَانٍ تَفْتَرُونَهُ بَيْنَ أَيْدِيكُمْ وَأَرْجُلِكُمْ، وَلاَ تَعْصُونِي فِي مَعْرُوفٍ، فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ، وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَأُخِذَ بِهِ فِي الدُّنْيَا فَهْوَ كَفَّارَةٌ لَهُ وَطَهُورٌ، وَمَنْ سَتَرَهُ اللَّهُ فَذَلِكَ إِلَى اللَّهِ، إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ غَفَرَ لَهُ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ إِذَا تَابَ السَّارِقُ بَعْدَ مَا قُطِعَ يَدُهُ، قُبِلَتْ شَهَادَتُهُ، وَكُلُّ مَحْدُودٍ كَذَلِكَ إِذَا تَابَ قُبِلَتْ شَهَادَتُهُ‏.‏\hadithno{6801}\hadithtrans{Narrated Ubada bin As-Samit:I gave the pledge of allegiance to the Prophet (ﷺ) with a group of people, and he said, "I take your pledge that you will not worship anything besides Allah, will not steal, will not commit infanticide, will not slander others by forging false statements and spreading it, and will not disobey me in anything good. And whoever among you fulfill all these (obligations of the pledge), his reward is with Allah. And whoever commits any of the above crimes and receives his legal punishment in this world, that will be his expiation and purification. But if Allah screens his sin, it will be up to Allah, Who will either punish or forgive him according to His wish." Abu `Abdullah said: "If a thief repents after his hand has been cut off, the his witness well be accepted. Similarly, if any person upon whom any legal punishment has been inflicted, repents, his witness will be accepted}}
\hadithdefcmd{bukhari}{6802}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ الْجَرْمِيُّ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم نَفَرٌ مِنْ عُكْلٍ، فَأَسْلَمُوا فَاجْتَوَوُا الْمَدِينَةَ، فَأَمَرَهُمْ أَنْ يَأْتُوا إِبِلَ الصَّدَقَةِ، فَيَشْرَبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا، فَفَعَلُوا فَصَحُّوا، فَارْتَدُّوا وَقَتَلُوا رُعَاتَهَا وَاسْتَاقُوا، فَبَعَثَ فِي آثَارِهِمْ فَأُتِيَ بِهِمْ، فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ، ثُمَّ لَمْ يَحْسِمْهُمْ حَتَّى مَاتُوا‏.‏\hadithno{6802}\hadithtrans{Narrated Anas:Some people from the tribe of `Ukl came to the Prophet (ﷺ) and embraced Islam. The climate of Medina did not suit them, so the Prophet (ﷺ) ordered them to go to the (herd of milch) camels of charity and to drink, their milk and urine (as a medicine). They did so, and after they had recovered from their ailment (became healthy) they turned renegades (reverted from Islam) and killed the shepherd of the camels and took the camels away. The Prophet (ﷺ) sent (some people) in their pursuit and so they were (caught and) brought, and the Prophets ordered that their hands and legs should be cut off and that their eyes should be branded with heated pieces of iron, and that their cut hands and legs should not be cauterized, till they die}}
\hadithdefcmd{bukhari}{6803}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّلْتِ أَبُو يَعْلَى، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنِي الأَوْزَاعِيُّ، عَنْ يَحْيَى، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَطَعَ الْعُرَنِيِّينَ وَلَمْ يَحْسِمْهُمْ حَتَّى مَاتُوا‏.‏\hadithno{6803}\hadithtrans{Narrated Anas:The Prophet (ﷺ) cut off the hands and feet of the men belonging to the tribe of `Uraina and did not cauterise (their bleeding limbs) till they died}}
\hadithdefcmd{bukhari}{6804}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، عَنْ وُهَيْبٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَدِمَ رَهْطٌ مِنْ عُكْلٍ عَلَى النَّبِيِّ صلى الله عليه وسلم كَانُوا فِي الصُّفَّةِ، فَاجْتَوَوُا الْمَدِينَةَ فَقَالُوا يَا رَسُولَ اللَّهِ أَبْغِنَا رِسْلاً‏.‏ فَقَالَ ‏ "‏ مَا أَجِدُ لَكُمْ إِلاَّ أَنْ تَلْحَقُوا بِإِبِلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏‏.‏ فَأَتَوْهَا فَشَرِبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا حَتَّى صَحُّوا وَسَمِنُوا، وَقَتَلُوا الرَّاعِيَ وَاسْتَاقُوا الذَّوْدَ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم الصَّرِيخُ، فَبَعَثَ الطَّلَبَ فِي آثَارِهِمْ، فَمَا تَرَجَّلَ النَّهَارُ حَتَّى أُتِيَ بِهِمْ، فَأَمَرَ بِمَسَامِيرَ فَأُحْمِيَتْ فَكَحَلَهُمْ وَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ، وَمَا حَسَمَهُمْ، ثُمَّ أُلْقُوا فِي الْحَرَّةِ يَسْتَسْقُونَ فَمَا سُقُوا حَتَّى مَاتُوا‏.‏ قَالَ أَبُو قِلاَبَةَ سَرَقُوا وَقَتَلُوا وَحَارَبُوا اللَّهَ وَرَسُولَهُ‏.‏\hadithno{6804}\hadithtrans{Narrated Anas:A group of people from `Ukl (tribe) came to the Prophet (ﷺ) and they were living with the people of As- Suffa, but they became ill as the climate of Medina did not suit them, so they said, "O Allah's Messenger (ﷺ)! Provide us with milk." The Prophet (ﷺ) said, I see no other way for you than to use the camels of Allah's Apostle." So they went and drank the milk and urine of the camels, (as medicine) and became healthy and fat. Then they killed the shepherd and took the camels away. When a help-seeker came to Allah's Apostle, he sent some men in their pursuit, and they were captured and brought before mid day. The Prophet ordered for some iron pieces to be made red hot, and their eyes were branded with them and their hands and feet were cut off and were not cauterized. Then they were put at a place called Al- Harra, and when they asked for water to drink they were not given till they died. (Abu Qilaba said, "Those people committed theft and murder and fought against Allah and His Apostle)}}
\hadithdefcmd{bukhari}{6805}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَهْطًا، مِنْ عُكْلٍ ـ أَوْ قَالَ عُرَيْنَةَ وَلاَ أَعْلَمُهُ إِلاَّ قَالَ مِنْ عُكْلٍ ـ قَدِمُوا الْمَدِينَةَ، فَأَمَرَ لَهُمُ النَّبِيُّ صلى الله عليه وسلم بِلِقَاحٍ، وَأَمَرَهُمْ أَنْ يَخْرُجُوا فَيَشْرَبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا، فَشَرِبُوا حَتَّى إِذَا بَرِئُوا قَتَلُوا الرَّاعِيَ وَاسْتَاقُوا النَّعَمَ، فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم غُدْوَةً فَبَعَثَ الطَّلَبَ فِي إِثْرِهِمْ، فَمَا ارْتَفَعَ النَّهَارُ حَتَّى جِيءَ بِهِمْ، فَأَمَرَ بِهِمْ فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَرَ أَعْيُنَهُمْ، فَأُلْقُوا بِالْحَرَّةِ يَسْتَسْقُونَ فَلاَ يُسْقَوْنَ‏.‏ قَالَ أَبُو قِلاَبَةَ هَؤُلاَءِ قَوْمٌ سَرَقُوا، وَقَتَلُوا، وَكَفَرُوا بَعْدَ إِيمَانِهِمْ، وَحَارَبُوا اللَّهَ وَرَسُولَهُ‏.‏\hadithno{6805}\hadithtrans{Narrated Anas bin Malik:A group of people from `Ukl (or `Uraina) tribe ----but I think he said that they were from `Ukl came to Medina and (they became ill, so) the Prophet (ﷺ) ordered them to go to the herd of (Milch) she-camels and told them to go out and drink the camels' urine and milk (as a medicine). So they went and drank it, and when they became healthy, they killed the shepherd and drove away the camels. This news reached the Prophet (ﷺ) early in the morning, so he sent (some) men in their pursuit and they were captured and brought to the Prophet (ﷺ) before midday. He ordered to cut off their hands and legs and their eyes to be branded with heated iron pieces and they were thrown at Al-Harra, and when they asked for water to drink, they were not given water. (Abu Qilaba said, "Those were the people who committed theft and murder and reverted to disbelief after being believers (Muslims), and fought against Allah and His Apostle}}
\hadithdefcmd{bukhari}{6806}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ سَبْعَةٌ يُظِلُّهُمُ اللَّهُ يَوْمَ الْقِيَامَةِ فِي ظِلِّهِ، يَوْمَ لاَ ظِلَّ إِلاَّ ظِلُّهُ إِمَامٌ عَادِلٌ، وَشَابٌّ نَشَأَ فِي عِبَادَةِ اللَّهِ، وَرَجُلٌ ذَكَرَ اللَّهَ فِي خَلاَءٍ فَفَاضَتْ عَيْنَاهُ، وَرَجُلٌ قَلْبُهُ مُعَلَّقٌ فِي الْمَسْجِدِ، وَرَجُلاَنِ تَحَابَّا فِي اللَّهِ، وَرَجُلٌ دَعَتْهُ امْرَأَةٌ ذَاتُ مَنْصِبٍ وَجَمَالٍ إِلَى نَفْسِهَا قَالَ إِنِّي أَخَافُ اللَّهَ‏.‏ وَرَجُلٌ تَصَدَّقَ بِصَدَقَةٍ فَأَخْفَاهَا، حَتَّى لاَ تَعْلَمَ شِمَالُهُ مَا صَنَعَتْ يَمِينُهُ ‏"‏‏.‏\hadithno{6806}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Seven (people) will be shaded by Allah by His Shade on the Day of Resurrection when there will be no shade except His Shade. (They will be), a just ruler, a young man who has been brought up in the worship of Allah, a man who remembers Allah in seclusion and his eyes are then flooded with tears, a man whose heart is attached to mosques (offers his compulsory congregational prayers in the mosque), two men who love each other for Allah's Sake, a man who is called by a charming lady of noble birth to commit illegal sexual intercourse with her, and he says, 'I am afraid of Allah,' and (finally), a man who gives in charity so secretly that his left hand does not know what his right hand has given}}
\hadithdefcmd{bukhari}{6807}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ‏.‏ وَحَدَّثَنِي خَلِيفَةُ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَكَّلَ لِي مَا بَيْنَ رِجْلَيْهِ وَمَا بَيْنَ لَحْيَيْهِ، تَوَكَّلْتُ لَهُ بِالْجَنَّةِ ‏"‏‏.‏\hadithno{6807}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) said, "Whoever guarantees me (the chastity of) what is between his legs (i.e. his private parts), and what is between his jaws (i.e., his tongue), I guarantee him Paradise}}
\hadithdefcmd{bukhari}{6808}{أَخْبَرَنَا دَاوُدُ بْنُ شَبِيبٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، أَخْبَرَنَا أَنَسٌ، قَالَ لأُحَدِّثَنَّكُمْ حَدِيثًا لاَ يُحَدِّثُكُمُوهُ أَحَدٌ بَعْدِي، سَمِعْتُهُ مِنَ النَّبِيِّ صلى الله عليه وسلم سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَقُومُ السَّاعَةُ ـ وَإِمَّا قَالَ مِنْ أَشْرَاطِ السَّاعَةِ ـ أَنْ يُرْفَعَ الْعِلْمُ وَيَظْهَرَ الْجَهْلُ، وَيُشْرَبَ الْخَمْرُ، وَيَظْهَرَ الزِّنَا، وَيَقِلَّ الرِّجَالُ، وَيَكْثُرَ النِّسَاءُ، حَتَّى يَكُونَ لِلْخَمْسِينَ امْرَأَةً الْقَيِّمُ الْوَاحِدُ ‏"‏‏.‏\hadithno{6808}\hadithtrans{Narrated Anas: I will narrate to you a narration which nobody will narrate to you after me. I heard that from the Prophet. I heard the Prophet (ﷺ) saying, "The Hour will not be established" or said: "From among the portents of the Hour is that the religious knowledge will betaken away (by the death of religious Scholars) and general ignorance (of religion) will appear; and the drinking of alcoholic drinks will be very common, and (open) illegal sexual intercourse will prevail, and men will decrease in number while women will increase so much so that, for fifty women there will only be one man to look after them}}
\hadithdefcmd{bukhari}{6809}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، أَخْبَرَنَا إِسْحَاقُ بْنُ يُوسُفَ، أَخْبَرَنَا الْفُضَيْلُ بْنُ غَزْوَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزْنِي الْعَبْدُ حِينَ يَزْنِي وَهْوَ مُؤْمِنٌ، وَلاَ يَسْرِقُ حِينَ يَسْرِقُ وَهْوَ مُؤْمِنٌ، وَلاَ يَشْرَبُ حِينَ يَشْرَبُ وَهْوَ مُؤْمِنٌ، وَلاَ يَقْتُلُ وَهْوَ مُؤْمِنٌ ‏"‏‏.‏ قَالَ عِكْرِمَةُ قُلْتُ لاِبْنِ عَبَّاسٍ كَيْفَ يُنْزَعُ الإِيمَانُ مِنْهُ قَالَ هَكَذَا ـ وَشَبَّكَ بَيْنَ أَصَابِعِهِ ثُمَّ أَخْرَجَهَا ـ فَإِنْ تَابَ عَادَ إِلَيْهِ هَكَذَا وَشَبَّكَ بَيْنَ أَصَابِعِهِ\hadithno{6809}\hadithtrans{Narrated 'Ikrima from Ibn 'Abbas: Allah's Messenger (ﷺ) said, "When a slave (of Allah) commits illegal sexual intercourse, he is not a believer at the time of committing it; and if he steals, he is not a believer at the time of stealing; and if he drinks an alcoholic drink, when he is not a believer at the time of drinking it; and he is not a believer when he commits a murder," 'Ikrima said: I asked Ibn Abbas, "How is faith taken away from him?" He said, Like this," by clasping his hands and then separating them, and added, "But if he repents, faith returns to him like this, by clasping his hands again}}
\hadithdefcmd{bukhari}{6810}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ ذَكْوَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهْوَ مُؤْمِنٌ، وَلاَ يَسْرِقُ حِينَ يَسْرِقُ وَهْوَ مُؤْمِنٌ، وَلاَ يَشْرَبُ حِينَ يَشْرَبُهَا وَهْوَ مُؤْمِنٌ، وَالتَّوْبَةُ مَعْرُوضَةٌ بَعْدُ ‏"‏‏.‏\hadithno{6810}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The one who commits an illegal sexual intercourse is not a believer at the time of committing illegal sexual intercourse and a thief is not a believer at the time of committing theft and a drinker of alcoholic drink is not a believer at the time of drinking. Yet, (the gate of) repentance is open thereafter}}
\hadithdefcmd{bukhari}{6811}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي مَنْصُورٌ، وَسُلَيْمَانُ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مَيْسَرَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الذَّنْبِ أَعْظَمُ قَالَ ‏"‏ أَنْ تَجْعَلَ لِلَّهِ نِدًّا وَهْوَ خَلَقَكَ ‏"‏‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ أَنْ تَقْتُلَ وَلَدَكَ مِنْ أَجْلِ أَنْ يَطْعَمَ مَعَكَ ‏"‏‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ أَنْ تُزَانِيَ حَلِيلَةَ جَارِكَ ‏"‏‏.‏ قَالَ يَحْيَى وَحَدَّثَنَا سُفْيَانُ، حَدَّثَنِي وَاصِلٌ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قُلْتُ يَا رَسُولَ اللَّهِ، مِثْلَهُ، قَالَ عَمْرٌو فَذَكَرْتُهُ لِعَبْدِ الرَّحْمَنِ وَكَانَ حَدَّثَنَا عَنْ سُفْيَانَ عَنِ الأَعْمَشِ وَمَنْصُورٍ وَوَاصِلٍ عَنْ أَبِي وَائِلٍ عَنْ أَبِي مَيْسَرَةَ قَالَ دَعْهُ دَعْهُ‏.‏\hadithno{6811}\hadithtrans{Narrated `Abdullah bin Mas`ud:I said, "O Allah's Messenger (ﷺ)! Which is the biggest sin?" He said, "To set up rivals to Allah by worshipping others though He alone has created you." I asked, "What is next?" He said, "To kill your child lest it should share your food." I asked, "What is next?" He said, "To commit illegal sexual intercourse with the wife of your neighbor}}
\hadithdefcmd{bukhari}{6812}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سَلَمَةُ بْنُ كُهَيْلٍ، قَالَ سَمِعْتُ الشَّعْبِيَّ، يُحَدِّثُ عَنْ عَلِيٍّ، رضى الله عنه حِينَ رَجَمَ الْمَرْأَةَ يَوْمَ الْجُمُعَةِ وَقَالَ قَدْ رَجَمْتُهَا بِسُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{6812}\hadithtrans{Narrated Ash-Shu`bi:from `Ali when the latter stoned a lady to death on a Friday. `Ali said, "I have stoned her according to the tradition of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{6813}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا خَالِدٌ، عَنِ الشَّيْبَانِيِّ، سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى هَلْ رَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ‏.‏ قُلْتُ قَبْلَ سُورَةِ النُّورِ أَمْ بَعْدُ قَالَ لاَ أَدْرِي‏.‏\hadithno{6813}\hadithtrans{Narrated Ash Shaibani:I asked `Abdullah bin Abi `Aufa, 'Did Allah's Messenger (ﷺ) carry out the Rajam penalty ( i.e., stoning to death)?' He said, "Yes." I said, "Before the revelation of Surat-an-Nur or after it?" He replied, "I don't Know}}
\hadithdefcmd{bukhari}{6814}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، أَنَّ رَجُلاً، مِنْ أَسْلَمَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَحَدَّثَهُ أَنَّهُ قَدْ زَنَى، فَشَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ، فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَ، وَكَانَ قَدْ أُحْصِنَ‏.‏\hadithno{6814}\hadithtrans{Narrated Jabir bin `Abdullah Al-Ansari:A man from the tribe of Bani Aslam came to Allah's Messenger (ﷺ) and Informed him that he had committed illegal sexual intercourse and bore witness four times against himself. Allah's Messenger (ﷺ) ordered him to be stoned to death as he was a married Person}}
\hadithdefcmd{bukhari}{6816}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي الْمَسْجِدِ فَنَادَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ‏.‏ فَأَعْرَضَ عَنْهُ، حَتَّى رَدَّدَ عَلَيْهِ أَرْبَعَ مَرَّاتٍ، فَلَمَّا شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ، دَعَاهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَبِكَ جُنُونٌ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَهَلْ أَحْصَنْتَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اذْهَبُوا بِهِ فَارْجُمُوهُ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي مَنْ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ فَكُنْتُ فِيمَنْ رَجَمَهُ فَرَجَمْنَاهُ بِالْمُصَلَّى، فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ هَرَبَ، فَأَدْرَكْنَاهُ بِالْحَرَّةِ فَرَجَمْنَاهُ‏.‏\hadithno{6816}\hadithtrans{Narrated Abu Huraira:A man came to Allah's Messenger (ﷺ) while he was in the mosque, and he called him, saying, "O Allah's Apostle! I have committed illegal sexual intercourse.'" The Prophet (ﷺ) turned his face to the other side, but that man repeated his statement four times, and after he bore witness against himself four times, the Prophet (ﷺ) called him, saying, "Are you mad?" The man said, "No." The Prophet (ﷺ) said, "Are you married?" The man said, "Yes." Then the Prophet (ﷺ) said, 'Take him away and stone him to death." Jabir bin `Abdullah said: I was among the ones who participated in stoning him and we stoned him at the Musalla. When the stones troubled him, he fled, but we over took him at Al-Harra and stoned him to death}}
\hadithdefcmd{bukhari}{6817}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اخْتَصَمَ سَعْدٌ وَابْنُ زَمْعَةَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هُوَ لَكَ يَا عَبْدُ بْنَ زَمْعَةَ، الْوَلَدُ لِلْفِرَاشِ، وَاحْتَجِبِي مِنْهُ يَا سَوْدَةُ ‏"‏‏.‏ زَادَ لَنَا قُتَيْبَةُ عَنِ اللَّيْثِ ‏"‏ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏‏.‏\hadithno{6817}\hadithtrans{Narrated `Aisha:Sa`d bin Abi Waqqas and `Abd bin Zam`a quarrelled with each other (regarding a child). The Prophet (ﷺ) said, "The boy is for you, O `Abd bin Zam`a, for the boy is for (the owner) of the bed. O Sauda ! Screen yourself from the boy." The sub-narrator, Al-Laith added (that the Prophet (ﷺ) also said), "And the stone is for the person who commits an illegal sexual intercourse}}
\hadithdefcmd{bukhari}{6818}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْوَلَدُ لِلْفِرَاشِ، وَلِلْعَاهِرِ الْحَجَرُ ‏"‏‏.‏\hadithno{6818}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The boy is for (the owner of) the bed and the stone is for the person who commits illegal sexual intercourse}}
\hadithdefcmd{bukhari}{6819}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَهُودِيٍّ وَيَهُودِيَّةٍ قَدْ أَحْدَثَا جَمِيعًا فَقَالَ لَهُمْ ‏ "‏ مَا تَجِدُونَ فِي كِتَابِكُمْ ‏"‏‏.‏ قَالُوا إِنَّ أَحْبَارَنَا أَحْدَثُوا تَحْمِيمَ الْوَجْهِ وَالتَّجْبِيَةَ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ادْعُهُمْ يَا رَسُولَ اللَّهِ بِالتَّوْرَاةِ‏.‏ فَأُتِيَ بِهَا فَوَضَعَ أَحَدُهُمْ يَدَهُ عَلَى آيَةِ الرَّجْمِ، وَجَعَلَ يَقْرَأُ مَا قَبْلَهَا وَمَا بَعْدَهَا فَقَالَ لَهُ ابْنُ سَلاَمٍ ارْفَعْ يَدَكَ‏.‏ فَإِذَا آيَةُ الرَّجْمِ تَحْتَ يَدِهِ، فَأَمَرَ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَا‏.‏ قَالَ ابْنُ عُمَرَ فَرُجِمَا عِنْدَ الْبَلاَطِ، فَرَأَيْتُ الْيَهُودِيَّ أَجْنَأَ عَلَيْهَا‏.‏\hadithno{6819}\hadithtrans{Narrated Ibn `Umar:A Jew and a Jewess were brought to Allah's Messenger (ﷺ) on a charge of committing an illegal sexual intercourse. The Prophet (ﷺ) asked them. "What is the legal punishment (for this sin) in your Book (Torah)?" They replied, "Our priests have innovated the punishment of blackening the faces with charcoal and Tajbiya." `Abdullah bin Salam said, "O Allah's Messenger (ﷺ), tell them to bring the Torah." The Torah was brought, and then one of the Jews put his hand over the Divine Verse of the Rajam (stoning to death) and started reading what preceded and what followed it. On that, Ibn Salam said to the Jew, "Lift up your hand." Behold! The Divine Verse of the Rajam was under his hand. So Allah's Apostle ordered that the two (sinners) be stoned to death, and so they were stoned. Ibn `Umar added: So both of them were stoned at the Balat and I saw the Jew sheltering the Jewess}}
\hadithdefcmd{bukhari}{6820}{حَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مِنْ أَسْلَمَ جَاءَ النَّبِيَّ صلى الله عليه وسلم فَاعْتَرَفَ بِالزِّنَا فَأَعْرَضَ عَنْهُ النَّبِيُّ صلى الله عليه وسلم حَتَّى شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ مَرَّاتٍ‏.‏ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبِكَ جُنُونٌ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ آحْصَنْتَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ فَأَمَرَ بِهِ فَرُجِمَ بِالْمُصَلَّى، فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ فَرَّ، فَأُدْرِكَ فَرُجِمَ حَتَّى مَاتَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم خَيْرًا وَصَلَّى عَلَيْهِ‏.‏ لَمْ يَقُلْ يُونُسُ وَابْنُ جُرَيْجٍ عَنِ الزُّهْرِيِّ فَصَلَّى عَلَيْهِ‏.‏\hadithno{6820}\hadithtrans{Narrated Jabir:A man from the tribe of Aslam came to the Prophet (ﷺ) and confessed that he had committed an illegal sexual intercourse. The Prophet (ﷺ) turned his face away from him till the man bore witness against himself four times. The Prophet (ﷺ) said to him, "Are you mad?" He said "No." He said, "Are you married?" He said, "Yes." Then the Prophet (ﷺ) ordered that he be stoned to death, and he was stoned to death at the Musalla. When the stones troubled him, he fled, but he was caught and was stoned till he died. The Prophet (ﷺ) spoke well of him and offered his funeral prayer}}
\hadithdefcmd{bukhari}{6821}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَجُلاً، وَقَعَ بِامْرَأَتِهِ فِي رَمَضَانَ، فَاسْتَفْتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ هَلْ تَجِدُ رَقَبَةً ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ هَلْ تَسْتَطِيعُ صِيَامَ شَهْرَيْنِ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَأَطْعِمْ سِتِّينَ مِسْكِينًا ‏"‏‏.‏\hadithno{6821}\hadithtrans{Narrated Abu Huraira: A person had sexual relation with his wife in the month of Ramadan (while he was fasting), and he came to Allah's Messenger (ﷺ) seeking his verdict concerning that action. The Prophet (ﷺ) said (to him), "Can you afford to manumit a slave?" The man said, "No." The Prophet (ﷺ) said, "Can you fast for two successive months?" He said, "No." The Prophet (ﷺ) said, "Then feed sixty poor persons}}
\hadithdefcmd{bukhari}{6822}{وَقَالَ اللَّيْثُ عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَتَى رَجُلٌ النَّبِيَّ صلى الله عليه وسلم فِي الْمَسْجِدِ قَالَ احْتَرَقْتُ‏.‏ قَالَ ‏"‏ مِمَّ ذَاكَ ‏"‏‏.‏ قَالَ وَقَعْتُ بِامْرَأَتِي فِي رَمَضَانَ‏.‏ قَالَ لَهُ ‏"‏ تَصَدَّقْ ‏"‏‏.‏ قَالَ مَا عِنْدِي شَىْءٌ‏.‏ فَجَلَسَ وَأَتَاهُ إِنْسَانٌ يَسُوقُ حِمَارًا وَمَعَهُ طَعَامٌ ـ قَالَ عَبْدُ الرَّحْمَنِ مَا أَدْرِي مَا هُوَ ـ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَيْنَ الْمُحْتَرِقُ ‏"‏‏.‏ فَقَالَ هَا أَنَا ذَا‏.‏ قَالَ ‏"‏ خُذْ هَذَا فَتَصَدَّقْ بِهِ ‏"‏‏.‏ قَالَ عَلَى أَحْوَجَ مِنِّي مَا لأَهْلِي طَعَامٌ قَالَ ‏"‏ فَكُلُوهُ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ الْحَدِيثُ الأَوَّلُ أَبْيَنُ قَوْلُهُ ‏"‏ أَطْعِمْ أَهْلَكَ ‏"‏‏.‏\hadithno{6822}\hadithtrans{Narrated 'Aisha: A man came to the Prophet (ﷺ) in the mosque and said, "I am burnt (ruined)!" The Prophet (ﷺ) asked him, "With what (what have you done)?" He said, "I have had sexual relation with my wife in the month of Ramadan (while fasting)." The Prophet (ﷺ) said to him, "Give in charity." He said, "I have nothing." The man sat down, and in the meantime there came a person driving a donkey carrying food to the Prophet (ﷺ) ..... (The sub-narrator, 'Abdur Rahman added: I do not know what kind of food it was). On that the Prophet (ﷺ) said, "Where is the burnt person?" The man said, "Here I am." The Prophet (ﷺ) said to him, "Take this (food) and give it in charity (to someone)." The man said, "To a poorer person than l? My family has nothing to eat." Then the Prophet (ﷺ) said to him, "Then eat it yourselves}}
\hadithdefcmd{bukhari}{6823}{حَدَّثَنِي عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ، حَدَّثَنِي عَمْرُو بْنُ عَاصِمٍ الْكِلاَبِيُّ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَجَاءَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ حَدًّا فَأَقِمْهُ عَلَىَّ‏.‏ قَالَ وَلَمْ يَسْأَلْهُ عَنْهُ‏.‏ قَالَ وَحَضَرَتِ الصَّلاَةُ فَصَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم فَلَمَّا قَضَى النَّبِيُّ صلى الله عليه وسلم الصَّلاَةَ قَامَ إِلَيْهِ الرَّجُلُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ حَدًّا، فَأَقِمْ فِيَّ كِتَابَ اللَّهِ‏.‏ قَالَ ‏"‏ أَلَيْسَ قَدْ صَلَّيْتَ مَعَنَا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَإِنَّ اللَّهَ قَدْ غَفَرَ لَكَ ذَنْبَكَ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ حَدَّكَ ‏"‏‏.‏\hadithno{6823}\hadithtrans{Narrated Anas bin Malik:While I was with the Prophet (ﷺ) a man came and said, "O Allah's Messenger (ﷺ)! I have committed a legally punishable sin; please inflict the legal punishment on me'.' The Prophet (ﷺ) did not ask him what he had done. Then the time for the prayer became due and the man offered prayer along with the Prophet (ﷺ) , and when the Prophet (ﷺ) had finished his prayer, the man again got up and said, "O Allah's Messenger (ﷺ)! I have committed a legally punishable sin; please inflict the punishment on me according to Allah's Laws." The Prophet (ﷺ) said, "Haven't you prayed with us?' He said, "Yes." The Prophet (ﷺ) said, "Allah has forgiven your sin." or said, "....your legally punishable sin}}
\hadithdefcmd{bukhari}{6824}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْجُعْفِيُّ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ يَعْلَى بْنَ حَكِيمٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا أَتَى مَاعِزُ بْنُ مَالِكٍ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ لَعَلَّكَ قَبَّلْتَ أَوْ غَمَزْتَ أَوْ نَظَرْتَ ‏"‏‏.‏ قَالَ لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ أَنِكْتَهَا ‏"‏‏.‏ لاَ يَكْنِي‏.‏ قَالَ فَعِنْدَ ذَلِكَ أَمَرَ بِرَجْمِهِ‏.‏\hadithno{6824}\hadithtrans{Narrated Ibn `Abbas:When Ma'iz bin Malik came to the Prophet (in order to confess), the Prophet (ﷺ) said to him, "Probably you have only kissed (the lady), or winked, or looked at her?" He said, "No, O Allah's Messenger (ﷺ)!" The Prophet said, using no euphemism, "Did you have sexual intercourse with her?" The narrator added: At that, (i.e. after his confession) the Prophet (ﷺ) ordered that he be stoned (to death)}}
\hadithdefcmd{bukhari}{6825}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ أَنَّ أَبَا هُرَيْرَةَ، قَالَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم رَجُلٌ مِنَ النَّاسِ وَهْوَ فِي الْمَسْجِدِ فَنَادَاهُ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ‏.‏ يُرِيدُ نَفْسَهُ، فَأَعْرَضَ عَنْهُ النَّبِيُّ صلى الله عليه وسلم فَتَنَحَّى لِشِقِّ وَجْهِهِ الَّذِي أَعْرَضَ قِبَلَهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ‏.‏ فَأَعْرَضَ عَنْهُ، فَجَاءَ لِشِقِّ وَجْهِ النَّبِيِّ صلى الله عليه وسلم الَّذِي أَعْرَضَ عَنْهُ، فَلَمَّا شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ دَعَاهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَبِكَ جُنُونٌ ‏"‏‏.‏ قَالَ لاَ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ أَحْصَنْتَ ‏"‏‏.‏ قَالَ نَعَمْ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ اذْهَبُوا فَارْجُمُوهُ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي مَنْ، سَمِعَ جَابِرًا، قَالَ فَكُنْتُ فِيمَنْ رَجَمَهُ، فَرَجَمْنَاهُ بِالْمُصَلَّى، فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ جَمَزَ حَتَّى أَدْرَكْنَاهُ بِالْحَرَّةِ فَرَجَمْنَاهُ‏.‏\hadithno{6825}\hadithtrans{Narrated Abu Huraira:A man from among the people, came to Allah's Messenger (ﷺ) while Allah's Messenger (ﷺ) was sitting in the mosque, and addressed him, saying, "O Allah's Messenger (ﷺ)! I have committed an illegal sexual intercourse." The Prophet (ﷺ) turned his face away from him. The man came to that side to which the Prophet had turned his face, and said, "O Allah's Messenger (ﷺ)! I have committed an illegal intercourse." The Prophet (ﷺ) turned his face to the other side, and the man came to that side, and when he confessed four times, the Prophet (ﷺ) called him and said, "Are you mad?" He said, "No, O Allah's Messenger (ﷺ)!" The Prophet said, "Are you married?" He said, "Yes, O Allah's Messenger (ﷺ)." The Prophet (ﷺ) said (to the people), "Take him away and stone him to death." Ibn Shihab added, "I was told by one who heard Jabir, that Jabir said, 'I was among those who stoned the man, and we stoned him at the Musalla (`Id praying Place), and when the stones troubled him, he jumped quickly and ran away, but we overtook him at Al-Harra and stoned him to death (there)}}
\hadithdefcmd{bukhari}{6828}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنْ فِي الزُّهْرِيِّ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ وَزَيْدَ بْنَ خَالِدٍ قَالاَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَامَ رَجُلٌ فَقَالَ أَنْشُدُكَ اللَّهَ إِلاَّ قَضَيْتَ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ ـ وَكَانَ أَفْقَهَ مِنْهُ ـ فَقَالَ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ وَأْذَنْ لِي‏.‏ قَالَ ‏"‏ قُلْ ‏"‏‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا، فَزَنَى بِامْرَأَتِهِ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَخَادِمٍ، ثُمَّ سَأَلْتُ رِجَالاً مِنْ أَهْلِ الْعِلْمِ، فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي جَلْدَ مِائَةٍ وَتَغْرِيبَ عَامٍ، وَعَلَى امْرَأَتِهِ الرَّجْمَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ جَلَّ ذِكْرُهُ، الْمِائَةُ شَاةٍ وَالْخَادِمُ رَدٌّ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَاغْدُ يَا أُنَيْسُ عَلَى امْرَأَةِ هَذَا، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا عَلَيْهَا فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏ قُلْتُ لِسُفْيَانَ لَمْ يَقُلْ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ‏.‏ فَقَالَ أَشُكُّ فِيهَا مِنَ الزُّهْرِيِّ، فَرُبَّمَا قُلْتُهَا وَرُبَّمَا سَكَتُّ‏.‏\hadithno{6828}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:While we were with the Prophet (ﷺ) , a man stood up and said (to the Prophet (ﷺ) ), "I beseech you by Allah, that you should judge us according to Allah's Laws." Then the man's opponent who was wiser than him, got up saying (to Allah's Messenger (ﷺ)) "Judge us according to Allah's Law and kindly allow me (to speak)." The Prophet (ﷺ) said, "'Speak." He said, "My son was a laborer working for this man and he committed an illegal sexual intercourse with his wife, and I gave one-hundred sheep and a slave as a ransom for my son's sin. Then I asked a learned man about this case and he informed me that my son should receive one hundred lashes and be exiled for one year, and the man's wife should be stoned to death." The Prophet (ﷺ) said, "By Him in Whose Hand my soul is, I will judge you according to the Laws of Allah. Your one-hundred sheep and the slave are to be returned to you, and your son has to receive one-hundred lashes and be exiled for one year. O Unais! Go to the wife of this man, and if she confesses, then stone her to death." Unais went to her and she confessed. He then stoned her to death}}
\hadithdefcmd{bukhari}{6829}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ عُمَرُ لَقَدْ خَشِيتُ أَنْ يَطُولَ بِالنَّاسِ زَمَانٌ حَتَّى يَقُولَ قَائِلٌ لاَ نَجِدُ الرَّجْمَ فِي كِتَابِ اللَّهِ‏.‏ فَيَضِلُّوا بِتَرْكِ فَرِيضَةٍ أَنْزَلَهَا اللَّهُ، أَلاَ وَإِنَّ الرَّجْمَ حَقٌّ عَلَى مَنْ زَنَى، وَقَدْ أَحْصَنَ، إِذَا قَامَتِ الْبَيِّنَةُ، أَوْ كَانَ الْحَمْلُ أَوْ الاِعْتِرَافُ ـ قَالَ سُفْيَانُ كَذَا حَفِظْتُ ـ أَلاَ وَقَدْ رَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَمْنَا بَعْدَهُ‏.‏\hadithno{6829}\hadithtrans{Narrated Ibn `Abbas:`Umar said, "I am afraid that after a long time has passed, people may say, "We do not find the Verses of the Rajam (stoning to death) in the Holy Book," and consequently they may go astray by leaving an obligation that Allah has revealed. Lo! I confirm that the penalty of Rajam be inflicted on him who commits illegal sexual intercourse, if he is already married and the crime is proved by witnesses or pregnancy or confession." Sufyan added, "I have memorized this narration in this way." `Umar added, "Surely Allah's Messenger (ﷺ) carried out the penalty of Rajam, and so did we after him}}
\hadithdefcmd{bukhari}{6830}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ أُقْرِئُ رِجَالاً مِنَ الْمُهَاجِرِينَ مِنْهُمْ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ، فَبَيْنَمَا أَنَا فِي مَنْزِلِهِ بِمِنًى، وَهْوَ عِنْدَ عُمَرَ بْنِ الْخَطَّابِ فِي آخِرِ حَجَّةٍ حَجَّهَا، إِذْ رَجَعَ إِلَىَّ عَبْدُ الرَّحْمَنِ فَقَالَ لَوْ رَأَيْتَ رَجُلاً أَتَى أَمِيرَ الْمُؤْمِنِينَ الْيَوْمَ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ هَلْ لَكَ فِي فُلاَنٍ يَقُولُ لَوْ قَدْ مَاتَ عُمَرُ لَقَدْ بَايَعْتُ فُلاَنًا، فَوَاللَّهِ مَا كَانَتْ بَيْعَةُ أَبِي بَكْرٍ إِلاَّ فَلْتَةً، فَتَمَّتْ‏.‏ فَغَضِبَ عُمَرُ ثُمَّ قَالَ إِنِّي إِنْ شَاءَ اللَّهُ لَقَائِمٌ الْعَشِيَّةَ فِي النَّاسِ، فَمُحَذِّرُهُمْ هَؤُلاَءِ الَّذِينَ يُرِيدُونَ أَنْ يَغْصِبُوهُمْ أُمُورَهُمْ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ لاَ تَفْعَلْ فَإِنَّ الْمَوْسِمَ يَجْمَعُ رَعَاعَ النَّاسِ وَغَوْغَاءَهُمْ، فَإِنَّهُمْ هُمُ الَّذِينَ يَغْلِبُونَ عَلَى قُرْبِكَ حِينَ تَقُومُ فِي النَّاسِ، وَأَنَا أَخْشَى أَنْ تَقُومَ فَتَقُولَ مَقَالَةً يُطَيِّرُهَا عَنْكَ كُلُّ مُطَيِّرٍ، وَأَنْ لاَ يَعُوهَا، وَأَنْ لاَ يَضَعُوهَا عَلَى مَوَاضِعِهَا، فَأَمْهِلْ حَتَّى تَقْدَمَ الْمَدِينَةَ فَإِنَّهَا دَارُ الْهِجْرَةِ وَالسُّنَّةِ، فَتَخْلُصَ بِأَهْلِ الْفِقْهِ وَأَشْرَافِ النَّاسِ، فَتَقُولَ مَا قُلْتَ مُتَمَكِّنًا، فَيَعِي أَهْلُ الْعِلْمِ مَقَالَتَكَ، وَيَضَعُونَهَا عَلَى مَوَاضِعِهَا‏.‏ فَقَالَ عُمَرُ أَمَا وَاللَّهِ إِنْ شَاءَ اللَّهُ لأَقُومَنَّ بِذَلِكَ أَوَّلَ مَقَامٍ أَقُومُهُ بِالْمَدِينَةِ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَقَدِمْنَا الْمَدِينَةَ فِي عَقِبِ ذِي الْحَجَّةِ، فَلَمَّا كَانَ يَوْمُ الْجُمُعَةِ عَجَّلْنَا الرَّوَاحَ حِينَ زَاغَتِ الشَّمْسُ، حَتَّى أَجِدَ سَعِيدَ بْنَ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ جَالِسًا إِلَى رُكْنِ الْمِنْبَرِ، فَجَلَسْتُ حَوْلَهُ تَمَسُّ رُكْبَتِي رُكْبَتَهُ، فَلَمْ أَنْشَبْ أَنْ خَرَجَ عُمَرُ بْنُ الْخَطَّابِ، فَلَمَّا رَأَيْتُهُ مُقْبِلاً قُلْتُ لِسَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، لَيَقُولَنَّ الْعَشِيَّةَ مَقَالَةً لَمْ يَقُلْهَا مُنْذُ اسْتُخْلِفَ، فَأَنْكَرَ عَلَىَّ وَقَالَ مَا عَسَيْتَ أَنْ يَقُولَ مَا لَمْ يَقُلْ‏.‏ قَبْلَهُ فَجَلَسَ عُمَرُ عَلَى الْمِنْبَرِ، فَلَمَّا سَكَتَ الْمُؤَذِّنُونَ قَامَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ قَالَ أَمَّا بَعْدُ فَإِنِّي قَائِلٌ لَكُمْ مَقَالَةً قَدْ قُدِّرَ لِي أَنْ أَقُولَهَا، لاَ أَدْرِي لَعَلَّهَا بَيْنَ يَدَىْ أَجَلِي، فَمَنْ عَقَلَهَا وَوَعَاهَا فَلْيُحَدِّثْ بِهَا حَيْثُ انْتَهَتْ بِهِ رَاحِلَتُهُ، وَمَنْ خَشِيَ أَنْ لاَ يَعْقِلَهَا فَلاَ أُحِلُّ لأَحَدٍ أَنْ يَكْذِبَ عَلَىَّ، إِنَّ اللَّهَ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ وَأَنْزَلَ عَلَيْهِ الْكِتَابَ فَكَانَ مِمَّا أَنْزَلَ اللَّهُ آيَةُ الرَّجْمِ، فَقَرَأْنَاهَا وَعَقَلْنَاهَا وَوَعَيْنَاهَا، رَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَمْنَا بَعْدَهُ، فَأَخْشَى إِنْ طَالَ بِالنَّاسِ زَمَانٌ أَنْ يَقُولَ قَائِلٌ وَاللَّهِ مَا نَجِدُ آيَةَ الرَّجْمِ فِي كِتَابِ اللَّهِ، فَيَضِلُّوا بِتَرْكِ فَرِيضَةٍ أَنْزَلَهَا اللَّهُ، وَالرَّجْمُ فِي كِتَابِ اللَّهِ حَقٌّ عَلَى مَنْ زَنَى إِذَا أُحْصِنَ مِنَ الرِّجَالِ وَالنِّسَاءِ، إِذَا قَامَتِ الْبَيِّنَةُ أَوْ كَانَ الْحَبَلُ أَوْ الاِعْتِرَافُ، ثُمَّ إِنَّا كُنَّا نَقْرَأُ فِيمَا نَقْرَأُ مِنْ كِتَابِ اللَّهِ أَنْ لاَ تَرْغَبُوا عَنْ آبَائِكُمْ، فَإِنَّهُ كُفْرٌ بِكُمْ أَنْ تَرْغَبُوا عَنْ آبَائِكُمْ، أَوْ إِنَّ كُفْرًا بِكُمْ أَنْ تَرْغَبُوا عَنْ آبَائِكُمْ، أَلاَ ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُطْرُونِي كَمَا أُطْرِيَ عِيسَى ابْنُ مَرْيَمَ وَقُولُوا عَبْدُ اللَّهِ وَرَسُولُهُ ‏"‏‏.‏ ثُمَّ إِنَّهُ بَلَغَنِي أَنَّ قَائِلاً مِنْكُمْ يَقُولُ وَاللَّهِ لَوْ مَاتَ عُمَرُ بَايَعْتُ فُلاَنًا‏.‏ فَلاَ يَغْتَرَّنَّ امْرُؤٌ أَنْ يَقُولَ إِنَّمَا كَانَتْ بَيْعَةُ أَبِي بَكْرٍ فَلْتَةً وَتَمَّتْ أَلاَ وَإِنَّهَا قَدْ كَانَتْ كَذَلِكَ وَلَكِنَّ اللَّهَ وَقَى شَرَّهَا، وَلَيْسَ مِنْكُمْ مَنْ تُقْطَعُ الأَعْنَاقُ إِلَيْهِ مِثْلُ أَبِي بَكْرٍ، مَنْ بَايَعَ رَجُلاً عَنْ غَيْرِ مَشُورَةٍ مِنَ الْمُسْلِمِينَ فَلاَ يُبَايَعُ هُوَ وَلاَ الَّذِي بَايَعَهُ تَغِرَّةً أَنْ يُقْتَلاَ، وَإِنَّهُ قَدْ كَانَ مِنْ خَبَرِنَا حِينَ تَوَفَّى اللَّهُ نَبِيَّهُ صلى الله عليه وسلم إِلاَّ أَنَّ الأَنْصَارَ خَالَفُونَا وَاجْتَمَعُوا بِأَسْرِهِمْ فِي سَقِيفَةِ بَنِي سَاعِدَةَ، وَخَالَفَ عَنَّا عَلِيٌّ وَالزُّبَيْرُ وَمَنْ مَعَهُمَا، وَاجْتَمَعَ الْمُهَاجِرُونَ إِلَى أَبِي بَكْرٍ فَقُلْتُ لأَبِي بَكْرٍ يَا أَبَا بَكْرٍ انْطَلِقْ بِنَا إِلَى إِخْوَانِنَا هَؤُلاَءِ مِنَ الأَنْصَارِ‏.‏ فَانْطَلَقْنَا نُرِيدُهُمْ فَلَمَّا دَنَوْنَا مِنْهُمْ لَقِيَنَا مِنْهُمْ رَجُلاَنِ صَالِحَانِ، فَذَكَرَا مَا تَمَالَى عَلَيْهِ الْقَوْمُ فَقَالاَ أَيْنَ تُرِيدُونَ يَا مَعْشَرَ الْمُهَاجِرِينَ فَقُلْنَا نُرِيدُ إِخْوَانَنَا هَؤُلاَءِ مِنَ الأَنْصَارِ‏.‏ فَقَالاَ لاَ عَلَيْكُمْ أَنْ لاَ تَقْرَبُوهُمُ اقْضُوا أَمْرَكُمْ‏.‏ فَقُلْتُ وَاللَّهِ لَنَأْتِيَنَّهُمْ‏.‏ فَانْطَلَقْنَا حَتَّى أَتَيْنَاهُمْ فِي سَقِيفَةِ بَنِي سَاعِدَةَ، فَإِذَا رَجُلٌ مُزَمَّلٌ بَيْنَ ظَهْرَانَيْهِمْ فَقُلْتُ مَنْ هَذَا فَقَالُوا هَذَا سَعْدُ بْنُ عُبَادَةَ‏.‏ فَقُلْتُ مَا لَهُ قَالُوا يُوعَكُ‏.‏ فَلَمَّا جَلَسْنَا قَلِيلاً تَشَهَّدَ خَطِيبُهُمْ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ أَمَّا بَعْدُ فَنَحْنُ أَنْصَارُ اللَّهِ وَكَتِيبَةُ الإِسْلاَمِ، وَأَنْتُمْ مَعْشَرَ الْمُهَاجِرِينَ رَهْطٌ، وَقَدْ دَفَّتْ دَافَّةٌ مِنْ قَوْمِكُمْ، فَإِذَا هُمْ يُرِيدُونَ أَنْ يَخْتَزِلُونَا مِنْ أَصْلِنَا وَأَنْ يَحْضُنُونَا مِنَ الأَمْرِ‏.‏ فَلَمَّا سَكَتَ أَرَدْتُ أَنْ أَتَكَلَّمَ وَكُنْتُ زَوَّرْتُ مَقَالَةً أَعْجَبَتْنِي أُرِيدُ أَنْ أُقَدِّمَهَا بَيْنَ يَدَىْ أَبِي بَكْرٍ، وَكُنْتُ أُدَارِي مِنْهُ بَعْضَ الْحَدِّ، فَلَمَّا أَرَدْتُ أَنْ أَتَكَلَّمَ قَالَ أَبُو بَكْرٍ عَلَى رِسْلِكَ‏.‏ فَكَرِهْتُ أَنْ أُغْضِبَهُ، فَتَكَلَّمَ أَبُو بَكْرٍ فَكَانَ هُوَ أَحْلَمَ مِنِّي وَأَوْقَرَ، وَاللَّهِ مَا تَرَكَ مِنْ كَلِمَةٍ أَعْجَبَتْنِي فِي تَزْوِيرِي إِلاَّ قَالَ فِي بَدِيهَتِهِ مِثْلَهَا أَوْ أَفْضَلَ مِنْهَا حَتَّى سَكَتَ فَقَالَ مَا ذَكَرْتُمْ فِيكُمْ مِنْ خَيْرٍ فَأَنْتُمْ لَهُ أَهْلٌ، وَلَنْ يُعْرَفَ هَذَا الأَمْرُ إِلاَّ لِهَذَا الْحَىِّ مِنْ قُرَيْشٍ، هُمْ أَوْسَطُ الْعَرَبِ نَسَبًا وَدَارًا، وَقَدْ رَضِيتُ لَكُمْ أَحَدَ هَذَيْنِ الرَّجُلَيْنِ، فَبَايِعُوا أَيَّهُمَا شِئْتُمْ‏.‏ فَأَخَذَ بِيَدِي وَبِيَدِ أَبِي عُبَيْدَةَ بْنِ الْجَرَّاحِ وَهْوَ جَالِسٌ بَيْنَنَا، فَلَمْ أَكْرَهْ مِمَّا قَالَ غَيْرَهَا، كَانَ وَاللَّهِ أَنْ أُقَدَّمَ فَتُضْرَبَ عُنُقِي لاَ يُقَرِّبُنِي ذَلِكَ مِنْ إِثْمٍ، أَحَبَّ إِلَىَّ مِنْ أَنْ أَتَأَمَّرَ عَلَى قَوْمٍ فِيهِمْ أَبُو بَكْرٍ، اللَّهُمَّ إِلاَّ أَنْ تُسَوِّلَ إِلَىَّ نَفْسِي عِنْدَ الْمَوْتِ شَيْئًا لاَ أَجِدُهُ الآنَ‏.‏ فَقَالَ قَائِلٌ مِنَ الأَنْصَارِ أَنَا جُذَيْلُهَا الْمُحَكَّكُ، وَعُذَيْقُهَا الْمُرَجَّبُ، مِنَّا أَمِيرٌ، وَمِنْكُمْ أَمِيرٌ، يَا مَعْشَرَ قُرَيْشٍ‏.‏ فَكَثُرَ اللَّغَطُ، وَارْتَفَعَتِ الأَصْوَاتُ حَتَّى فَرِقْتُ مِنَ الاِخْتِلاَفِ‏.‏ فَقُلْتُ ابْسُطْ يَدَكَ يَا أَبَا بَكْرٍ‏.‏ فَبَسَطَ يَدَهُ فَبَايَعْتُهُ، وَبَايَعَهُ الْمُهَاجِرُونَ، ثُمَّ بَايَعَتْهُ الأَنْصَارُ، وَنَزَوْنَا عَلَى سَعْدِ بْنِ عُبَادَةَ فَقَالَ قَائِلٌ مِنْهُمْ قَتَلْتُمْ سَعْدَ بْنَ عُبَادَةَ‏.‏ فَقُلْتُ قَتَلَ اللَّهُ سَعْدَ بْنَ عُبَادَةَ‏.‏ قَالَ عُمَرُ وَإِنَّا وَاللَّهِ مَا وَجَدْنَا فِيمَا حَضَرْنَا مِنْ أَمْرٍ أَقْوَى مِنْ مُبَايَعَةِ أَبِي بَكْرٍ خَشِينَا إِنْ فَارَقْنَا الْقَوْمَ وَلَمْ تَكُنْ بَيْعَةٌ أَنْ يُبَايِعُوا رَجُلاً مِنْهُمْ بَعْدَنَا، فَإِمَّا بَايَعْنَاهُمْ عَلَى مَا لاَ نَرْضَى، وَإِمَّا نُخَالِفُهُمْ فَيَكُونُ فَسَادٌ، فَمَنْ بَايَعَ رَجُلاً عَلَى غَيْرِ مَشُورَةٍ مِنَ الْمُسْلِمِينَ فَلاَ يُتَابَعُ هُوَ وَلاَ الَّذِي بَايَعَهُ تَغِرَّةً أَنْ يُقْتَلاَ‏.‏\hadithno{6830}\hadithtrans{Narrated Ibn `Abbas:I used to teach (the Qur'an to) some people of the Muhajirln (emigrants), among whom there was `Abdur Rahman bin `Auf. While I was in his house at Mina, and he was with `Umar bin Al-Khattab during `Umar's last Hajj, `Abdur-Rahman came to me and said, "Would that you had seen the man who came today to the Chief of the Believers (`Umar), saying, 'O Chief of the Believers! What do you think about so-and-so who says, 'If `Umar should die, I will give the pledge of allegiance to such-andsuch person, as by Allah, the pledge of allegiance to Abu Bakr was nothing but a prompt sudden action which got established afterwards.' `Umar became angry and then said, 'Allah willing, I will stand before the people tonight and warn them against those people who want to deprive the others of their rights (the question of rulership). `Abdur-Rahman said, "I said, 'O Chief of the believers! Do not do that, for the season of Hajj gathers the riff-raff and the rubble, and it will be they who will gather around you when you stand to address the people. And I am afraid that you will get up and say something, and some people will spread your statement and may not say what you have actually said and may not understand its meaning, and may interpret it incorrectly, so you should wait till you reach Medina, as it is the place of emigration and the place of Prophet's Traditions, and there you can come in touch with the learned and noble people, and tell them your ideas with confidence; and the learned people will understand your statement and put it in its proper place.' On that, `Umar said, 'By Allah! Allah willing, I will do this in the first speech I will deliver before the people in Medina." Ibn `Abbas added: We reached Medina by the end of the month of Dhul-Hijja, and when it was Friday, we went quickly (to the mosque) as soon as the sun had declined, and I saw Sa`id bin Zaid bin `Amr bin Nufail sitting at the corner of the pulpit, and I too sat close to him so that my knee was touching his knee, and after a short while `Umar bin Al-Khattab came out, and when I saw him coming towards us, I said to Sa`id bin Zaid bin `Amr bin Nufail "Today `Umar will say such a thing as he has never said since he was chosen as Caliph." Sa`id denied my statement with astonishment and said, "What thing do you expect `Umar to say the like of which he has never said before?" In the meantime, `Umar sat on the pulpit and when the callmakers for the prayer had finished their call, `Umar stood up, and having glorified and praised Allah as He deserved, he said, "Now then, I am going to tell you something which (Allah) has written for me to say. I do not know; perhaps it portends my death, so whoever understands and remembers it, must narrate it to the others wherever his mount takes him, but if somebody is afraid that he does not understand it, then it is unlawful for him to tell lies about me. Allah sent Muhammad with the Truth and revealed the Holy Book to him, and among what Allah revealed, was the Verse of the Rajam (the stoning of married person (male \& female) who commits illegal sexual intercourse, and we did recite this Verse and understood and memorized it. Allah's Messenger (ﷺ) did carry out the punishment of stoning and so did we after him. I am afraid that after a long time has passed, somebody will say, 'By Allah, we do not find the Verse of the Rajam in Allah's Book,' and thus they will go astray by leaving an obligation which Allah has revealed. And the punishment of the Rajam is to be inflicted to any married person (male \& female), who commits illegal sexual intercourse, if the required evidence is available or there is conception or confession. And then we used to recite among the Verses in Allah's Book: 'O people! Do not claim to be the offspring of other than your fathers, as it is disbelief (unthankfulness) on your part that you claim to be the offspring of other than your real father.' Then Allah's Messenger (ﷺ) said, 'Do not praise me excessively as Jesus, son of Marry was praised, but call me Allah's Slave and His Apostles.' (O people!) I have been informed that a speaker amongst you says, 'By Allah, if `Umar should die, I will give the pledge of allegiance to such-and-such person.' One should not deceive oneself by saying that the pledge of allegiance given to Abu Bakr was given suddenly and it was successful. No doubt, it was like that, but Allah saved (the people) from its evil, and there is none among you who has the qualities of Abu Bakr. Remember that whoever gives the pledge of allegiance to anybody among you without consulting the other Muslims, neither that person, nor the person to whom the pledge of allegiance was given, are to be supported, lest they both should be killed. And no doubt after the death of the Prophet (ﷺ) we were informed that the Ansar disagreed with us and gathered in the shed of Bani Sa`da. `Ali and Zubair and whoever was with them, opposed us, while the emigrants gathered with Abu Bakr. I said to Abu Bakr, 'Let's go to these Ansari brothers of ours.' So we set out seeking them, and when we approached them, two pious men of theirs met us and informed us of the final decision of the Ansar, and said, 'O group of Muhajirin (emigrants) ! Where are you going?' We replied, 'We are going to these Ansari brothers of ours.' They said to us, 'You shouldn't go near them. Carry out whatever we have already decided.' I said, 'By Allah, we will go to them.' And so we proceeded until we reached them at the shed of Bani Sa`da. Behold! There was a man sitting amongst them and wrapped in something. I asked, 'Who is that man?' They said, 'He is Sa`d bin 'Ubada.' I asked, 'What is wrong with him?' They said, 'He is sick.' After we sat for a while, the Ansar's speaker said, 'None has the right to be worshipped but Allah,' and praising Allah as He deserved, he added, 'To proceed, we are Allah's Ansar (helpers) and the majority of the Muslim army, while you, the emigrants, are a small group and some people among you came with the intention of preventing us from practicing this matter (of caliphate) and depriving us of it.' When the speaker had finished, I intended to speak as I had prepared a speech which I liked and which I wanted to deliver in the presence of Abu Bakr, and I used to avoid provoking him. So, when I wanted to speak, Abu Bakr said, 'Wait a while.' I disliked to make him angry. So Abu Bakr himself gave a speech, and he was wiser and more patient than I. By Allah, he never missed a sentence that I liked in my own prepared speech, but he said the like of it or better than it spontaneously. After a pause he said, 'O Ansar! You deserve all (the qualities that you have attributed to yourselves, but this question (of Caliphate) is only for the Quraish as they are the best of the Arabs as regards descent and home, and I am pleased to suggest that you choose either of these two men, so take the oath of allegiance to either of them as you wish. And then Abu Bakr held my hand and Abu Ubaida bin al-Jarrah's hand who was sitting amongst us. I hated nothing of what he had said except that proposal, for by Allah, I would rather have my neck chopped off as expiator for a sin than become the ruler of a nation, one of whose members is Abu Bakr, unless at the time of my death my own-self suggests something I don't feel at present.' And then one of the Ansar said, 'I am the pillar on which the camel with a skin disease (eczema) rubs itself to satisfy the itching (i.e., I am a noble), and I am as a high class palm tree! O Quraish. There should be one ruler from us and one from you.' Then there was a hue and cry among the gathering and their voices rose so that I was afraid there might be great disagreement, so I said, 'O Abu Bakr! Hold your hand out.' He held his hand out and I pledged allegiance to him, and then all the emigrants gave the Pledge of allegiance and so did the Ansar afterwards. And so we became victorious over Sa`d bin Ubada (whom Al-Ansar wanted to make a ruler). One of the Ansar said, 'You have killed Sa`d bin Ubada.' I replied, 'Allah has killed Sa`d bin Ubada.' `Umar added, "By Allah, apart from the great tragedy that had happened to us (i.e. the death of the Prophet), there was no greater problem than the allegiance pledged to Abu Bakr because we were afraid that if we left the people, they might give the Pledge of allegiance after us to one of their men, in which case we would have given them our consent for something against our real wish, or would have opposed them and caused great trouble. So if any person gives the Pledge of allegiance to somebody (to become a Caliph) without consulting the other Muslims, then the one he has selected should not be granted allegiance, lest both of them should be killed}}
\hadithdefcmd{bukhari}{6832}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَأْمُرُ فِيمَنْ زَنَى وَلَمْ يُحْصَنْ جَلْدَ مِائَةٍ وَتَغْرِيبَ عَامٍ‏.‏ قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي عُرْوَةَ بْنُ الزُّبَيْرِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، غَرَّبَ، ثُمَّ لَمْ تَزَلْ تِلْكَ السُّنَّةَ‏.‏\hadithno{6832}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:I heard the Prophet (ﷺ) ordering that an unmarried person guilty of illegal sexual intercourse be flogged one-hundred stripes and be exiled for one year. `Umar bin Al-Khattab also exiled such a person, and this tradition is still valid}}
\hadithdefcmd{bukhari}{6833}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِيمَنْ زَنَى وَلَمْ يُحْصَنْ بِنَفْىِ عَامٍ بِإِقَامَةِ الْحَدِّ عَلَيْهِ‏.‏\hadithno{6833}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) judged that the unmarried person who was guilty of illegal sexual intercourse be exiled for one year and receive the legal punishment (i.e., be flogged with one-hundred stripes)}}
\hadithdefcmd{bukhari}{6834}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا يَحْيَى، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَعَنَ النَّبِيُّ صلى الله عليه وسلم الْمُخَنَّثِينَ مِنَ الرِّجَالِ، وَالْمُتَرَجِّلاَتِ مِنَ النِّسَاءِ، وَقَالَ ‏ "‏ أَخْرِجُوهُمْ مِنْ بُيُوتِكُمْ ‏"‏‏.‏ وَأَخْرَجَ فُلاَنًا، وَأَخْرَجَ عُمَرُ فُلاَنًا‏.‏\hadithno{6834}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) cursed the effeminate men and those women who assume the similitude (manners) of men. He also said, "Turn them out of your houses." He turned such-and-such person out, and `Umar also turned out such-and-such person}}
\hadithdefcmd{bukhari}{6836}{حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، أَنَّ رَجُلاً، مِنَ الأَعْرَابِ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ جَالِسٌ فَقَالَ يَا رَسُولَ اللَّهِ اقْضِ بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ فَقَالَ صَدَقَ اقْضِ لَهُ يَا رَسُولَ اللَّهِ بِكِتَابِ اللَّهِ، إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا فَزَنَى بِامْرَأَتِهِ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ بِمِائَةٍ مِنَ الْغَنَمِ وَوَلِيدَةٍ، ثُمَّ سَأَلْتُ أَهْلَ الْعِلْمِ، فَزَعَمُوا أَنَّ مَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ‏.‏ فَقَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا الْغَنَمُ وَالْوَلِيدَةُ فَرَدٌّ عَلَيْكَ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَأَمَّا أَنْتَ يَا أُنَيْسُ فَاغْدُ عَلَى امْرَأَةِ هَذَا فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا أُنَيْسٌ فَرَجَمَهَا‏.‏\hadithno{6836}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:A bedouin came to the Prophet (ﷺ) while he (the Prophet) was sitting, and said, "O Allah's Messenger (ﷺ)! Give your verdict according to Allah's Laws (in our case)." Then his opponent got up and said, "He has told the truth, O Allah's Messenger (ﷺ)! Decide his case according to Allah's Laws. My son was a laborer working for this person, and he committed illegal sexual intercourse with his wife, and the people told me that my son should be stoned to death, but I offered one-hundred sheep and a slave girl as a ransom for him. Then I asked the religious learned people, and they told me that my son should be flogged with one-hundred stripes and be exiled for one year." The Prophet (ﷺ) said, "By Him in Whose Hand my soul is, I will judge you according to Allah's Laws. The sheep and the slave girl will be returned to you and your son will be flogged one-hundred stripes and be exiled for one year. And you, O Unais! Go to the wife of this man (and if she confesses), stone her to death." So Unais went in the morning and stoned her to death (after she had confessed)}}
\hadithdefcmd{bukhari}{6838}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الأَمَةِ إِذَا زَنَتْ وَلَمْ تُحْصَنْ قَالَ ‏ "‏ إِذَا زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا، ثُمَّ بِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ لاَ أَدْرِي بَعْدَ الثَّالِثَةِ أَوِ الرَّابِعَةِ‏.‏\hadithno{6838}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:The verdict of Allah's Messenger (ﷺ) was sought about an unmarried slave girl guilty of illegal intercourse. He replied, "If she commits illegal sexual intercourse, then flog her (fifty stripes), and if she commits illegal sexual intercourse (after that for the second time), then flog her (fifty stripes), and if she commits illegal sexual intercourse (for the third time), then flog her (fifty stripes) and sell her for even a hair rope." Ibn Shihab said, "I am not sure whether the Prophet (ﷺ) ordered that she be sold after the third or fourth time of committing illegal intercourse}}
\hadithdefcmd{bukhari}{6839}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَهُ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا زَنَتِ الأَمَةُ فَتَبَيَّنَ زِنَاهَا فَلْيَجْلِدْهَا وَلاَ يُثَرِّبْ، ثُمَّ إِنْ زَنَتْ فَلْيَجْلِدْهَا وَلاَ يُثَرِّبْ، ثُمَّ إِنْ زَنَتِ الثَّالِثَةَ فَلْيَبِعْهَا وَلَوْ بِحَبْلٍ مِنْ شَعَرٍ ‏"‏‏.‏ تَابَعَهُ إِسْمَاعِيلُ بْنُ أُمَيَّةَ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6839}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If a lady slave commits illegal sexual intercourse and she is proved guilty of illegal sexual intercourse, then she should be flogged (fifty stripes) but she should not be admonished; and if she commits illegal sexual intercourse again, then she should be flogged again but should not be admonished; and if she commits illegal sexual intercourse for the third time, then she should be sold even for a hair rope}}
\hadithdefcmd{bukhari}{6840}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الشَّيْبَانِيُّ، سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى عَنِ الرَّجْمِ، فَقَالَ رَجَمَ النَّبِيُّ صلى الله عليه وسلم‏.‏ فَقُلْتُ أَقَبْلَ النُّورِ أَمْ بَعْدَهُ قَالَ لاَ أَدْرِي‏.‏ تَابَعَهُ عَلِيُّ بْنُ مُسْهِرٍ وَخَالِدُ بْنُ عَبْدِ اللَّهِ وَالْمُحَارِبِيُّ وَعَبِيدَةُ بْنُ حُمَيْدٍ عَنِ الشَّيْبَانِيِّ‏.‏ وَقَالَ بَعْضُهُمُ الْمَائِدَةُ‏.‏ وَالأَوَّلُ أَصَحُّ‏.‏\hadithno{6840}\hadithtrans{Narrated Ash-Shaibani:I asked `Abdullah bin Abi `Aufa about the Rajam (stoning somebody to death for committing illegal sexual intercourse). He replied, "The Prophet (ﷺ) carried out the penalty of Rajam," I asked, "Was that before or after the revelation of Surat-an-Nur?" He replied, "I do not know}}
\hadithdefcmd{bukhari}{6841}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ قَالَ إِنَّ الْيَهُودَ جَاءُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا لَهُ أَنَّ رَجُلاً مِنْهُمْ وَامْرَأَةً زَنَيَا فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَجِدُونَ فِي التَّوْرَاةِ فِي شَأْنِ الرَّجْمِ ‏"‏‏.‏ فَقَالُوا نَفْضَحُهُمْ وَيُجْلَدُونَ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ كَذَبْتُمْ إِنَّ فِيهَا الرَّجْمَ‏.‏ فَأَتَوْا بِالتَّوْرَاةِ فَنَشَرُوهَا، فَوَضَعَ أَحَدُهُمْ يَدَهُ عَلَى آيَةِ الرَّجْمِ فَقَرَأَ مَا قَبْلَهَا وَمَا بَعْدَهَا‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ارْفَعْ يَدَكَ‏.‏ فَرَفَعَ يَدَهُ فَإِذَا فِيهَا آيَةُ الرَّجْمِ‏.‏ قَالُوا صَدَقَ يَا مُحَمَّدُ فِيهَا آيَةُ الرَّجْمِ‏.‏ فَأَمَرَ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَا، فَرَأَيْتُ الرَّجُلَ يَحْنِي عَلَى الْمَرْأَةِ يَقِيهَا الْحِجَارَةَ‏.‏\hadithno{6841}\hadithtrans{Narrated `Abdullah bin `Umar:The jews came to Allah's Messenger (ﷺ) and mentioned to him that a man and a lady among them had committed illegal sexual intercourse. Allah's Messenger (ﷺ) said to them, "What do you find in the Torah regarding the Rajam?" They replied, "We only disgrace and flog them with stripes." `Abdullah bin Salam said to them, 'You have told a lie the penalty of Rajam is in the Torah.' They brought the Torah and opened it. One of them put his hand over the verse of the Rajam and read what was before and after it. `Abdullah bin Salam said to him, "Lift up your hand." Where he lifted it there appeared the verse of the Rajam. So they said, "O Muhammad! He has said the truth, the verse of the Rajam is in it (Torah)." Then Allah's Messenger (ﷺ) ordered that the two persons (guilty of illegal sexual intercourse) be stoned to death, and so they were stoned, and I saw the man bending over the woman so as to protect her from the stones}}
\hadithdefcmd{bukhari}{6843}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، أَنَّهُمَا أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ وَقَالَ الآخَرُ وَهْوَ أَفْقَهُهُمَا أَجَلْ يَا رَسُولَ اللَّهِ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ، وَأْذَنْ لِي أَنْ أَتَكَلَّمَ‏.‏ قَالَ ‏"‏ تَكَلَّمْ ‏"‏‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا ـ قَالَ مَالِكٌ وَالْعَسِيفُ الأَجِيرُ ـ فَزَنَى بِامْرَأَتِهِ، فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَبِجَارِيَةٍ لِي، ثُمَّ إِنِّي سَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّ مَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَإِنَّمَا الرَّجْمُ عَلَى امْرَأَتِهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا غَنَمُكَ وَجَارِيَتُكَ فَرَدٌّ عَلَيْكَ ‏"‏‏.‏ وَجَلَدَ ابْنَهُ مِائَةً وَغَرَّبَهُ عَامًا، وَأَمَرَ أُنَيْسًا الأَسْلَمِيَّ أَنْ يَأْتِيَ امْرَأَةَ الآخَرِ، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا، فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏\hadithno{6843}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:Two men had a dispute in the presence of Allah's Messenger (ﷺ). One of them said, "Judge us according to Allah's Laws." The other who was more wise said, "Yes, Allah's Messenger (ﷺ), judge us according to Allah's Laws and allow me to speak (first)" The Prophet (ﷺ) said to him, 'Speak " He said, "My son was a laborer for this man, and he committed illegal sexual intercourse with his wife, and the people told me that my son should be stoned to death, but I have given one-hundred sheep and a slave girl as a ransom (expiation) for my son's sin. Then I asked the religious learned people (about It), and they told me that my son should he flogged one-hundred stripes and should be exiled for one year, and only the wife of this man should be stoned to death " Allah's Messenger (ﷺ) said, "By Him in Whose Hand my soul is, I will judge you according to Allah's Laws: O man, as for your sheep and slave girl, they are to be returned to you." Then the Prophet (ﷺ) had the man's son flogged one hundred stripes and exiled for one year, and ordered Unais Al-Aslami to go to the wife of the other man, and if she confessed, stone her to death. She confessed and was stoned to death}}
\hadithdefcmd{bukhari}{6844}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَ أَبُو بَكْرِ ـ رضى الله عنه ـ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاضِعٌ رَأْسَهُ عَلَى فَخِذِي فَقَالَ حَبَسْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالنَّاسَ، وَلَيْسُوا عَلَى مَاءٍ‏.‏ فَعَاتَبَنِي، وَجَعَلَ يَطْعُنُ بِيَدِهِ فِي خَاصِرَتِي، وَلاَ يَمْنَعُنِي مِنَ التَّحَرُّكِ إِلاَّ مَكَانُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ آيَةَ التَّيَمُّمِ‏.‏\hadithno{6844}\hadithtrans{Narrated `Aisha:Abu Bakr came to me while Allah's Messenger (ﷺ) was sleeping with his head on my thigh. Abu Bakr said (to me), "You have detained Allah's Messenger (ﷺ) and the people, and there is no water in this place." So he admonished me and struck my flanks with his hand, and nothing could stop me from moving except the reclining of Allah's Messenger (ﷺ) (on my thigh), and then Allah revealed the Divine Verse of Tayammum}}
\hadithdefcmd{bukhari}{6845}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَقْبَلَ أَبُو بَكْرٍ فَلَكَزَنِي لَكْزَةً شَدِيدَةً وَقَالَ حَبَسْتِ النَّاسَ فِي قِلاَدَةٍ‏.‏ فَبِي الْمَوْتُ لِمَكَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ أَوْجَعَنِي‏.‏ نَحْوَهُ‏.‏ لَكَزَ وَوَكَزَ وَاحِدٌ\hadithno{6845}\hadithtrans{Narrated Aisha:Abu Bakr came to towards me and struck me violently with his fist and said, "You have detained the people because of your necklace." But I remained motionless as if I was dead lest I should awake Allah's Messenger (ﷺ) although that hit was very painful}}
\hadithdefcmd{bukhari}{6846}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ وَرَّادٍ، كَاتِبِ الْمُغِيرَةِ عَنِ الْمُغِيرَةِ، قَالَ قَالَ سَعْدُ بْنُ عُبَادَةَ لَوْ رَأَيْتُ رَجُلاً مَعَ امْرَأَتِي لَضَرَبْتُهُ بِالسَّيْفِ غَيْرَ مُصْفَحٍ‏.‏ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَتَعْجَبُونَ مِنْ غَيْرَةِ سَعْدٍ، لأَنَا أَغْيَرُ مِنْهُ، وَاللَّهُ أَغْيَرُ مِنِّي ‏"‏‏.‏\hadithno{6846}\hadithtrans{Narrated Al-Mughira:Sa`d bin Ubada said, "If I found a man with my wife, I would kill him with the sharp side of my sword." When the Prophet (ﷺ) heard that he said, "Do you wonder at Sa`d's sense of ghira (self-respect)? Verily, I have more sense of ghira than Sa`d, and Allah has more sense of ghira than I}}
\hadithdefcmd{bukhari}{6847}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَهُ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ‏.‏ فَقَالَ ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ مَا أَلْوَانُهَا ‏"‏‏.‏ قَالَ حُمْرٌ‏.‏ قَالَ ‏"‏ فِيهَا مِنْ أَوْرَقَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَأَنَّى كَانَ ذَلِكَ ‏"‏‏.‏ قَالَ أُرَاهُ عِرْقٌ نَزَعَهُ‏.‏ قَالَ ‏"‏ فَلَعَلَّ ابْنَكَ هَذَا نَزَعَهُ عِرْقٌ ‏"‏‏.‏\hadithno{6847}\hadithtrans{Narrated Abu Huraira:A bedouin came to Allah's Messenger (ﷺ) and said, "My wife has delivered a black child." The Prophet (ﷺ) said to him, "Have you camels?" He replied, "Yes." The Prophet (ﷺ) said, "What color are they?" He replied, "They are red." The Prophet (ﷺ) further asked, "Are any of them gray in color?" He replied, "Yes." The Prophet asked him, "Whence did that grayness come?" He said, "I thing it descended from the camel's ancestors." Then the Prophet (ﷺ) said (to him), "Therefore, this child of yours has most probably inherited the color from his ancestors}}
\hadithdefcmd{bukhari}{6848}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يُجْلَدُ فَوْقَ عَشْرِ جَلَدَاتٍ إِلاَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏‏.‏\hadithno{6848}\hadithtrans{Narrated Abu Burda:The Prophet (ﷺ) used to say, "Nobody should be flogged more than ten stripes except if he is guilty of a crime, the legal punishment of which is assigned by Allah}}
\hadithdefcmd{bukhari}{6849}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُسْلِمُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ جَابِرٍ، عَمَّنْ سَمِعَ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عُقُوبَةَ فَوْقَ عَشْرِ ضَرَبَاتٍ إِلاَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏‏.‏\hadithno{6849}\hadithtrans{Narrated `Abdur-Rahman bin Jabir:On the authority of others, that the Prophet (ﷺ) said, "No Punishment exceeds the flogging of the ten stripes, except if one is guilty of a crime necessitating a legal punishment prescribed by Allah}}
\hadithdefcmd{bukhari}{6850}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ بُكَيْرًا، حَدَّثَهُ قَالَ بَيْنَمَا أَنَا جَالِسٌ، عِنْدَ سُلَيْمَانَ بْنِ يَسَارٍ إِذْ جَاءَ عَبْدُ الرَّحْمَنِ بْنُ جَابِرٍ فَحَدَّثَ سُلَيْمَانَ بْنَ يَسَارٍ، ثُمَّ أَقْبَلَ عَلَيْنَا سُلَيْمَانُ بْنُ يَسَارٍ فَقَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ جَابِرٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا بُرْدَةَ الأَنْصَارِيَّ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَجْلِدُوا فَوْقَ عَشْرَةِ أَسْوَاطٍ إِلاَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏‏.‏\hadithno{6850}\hadithtrans{Narrated Abu Burda Al-Ansari:I heard the Prophet (ﷺ) saying, "Do not flog anyone more than ten stripes except if he is involved in a crime necessitating Allah's legal Punishment}}
\hadithdefcmd{bukhari}{6851}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنَا أَبُو سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوِصَالِ فَقَالَ لَهُ رِجَالٌ مِنَ الْمُسْلِمِينَ فَإِنَّكَ يَا رَسُولَ اللَّهِ تُوَاصِلُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّكُمْ مِثْلِي إِنِّي أَبِيتُ يُطْعِمُنِي رَبِّي وَيَسْقِينِ ‏"‏‏.‏ فَلَمَّا أَبَوْا أَنْ يَنْتَهُوا عَنِ الْوِصَالِ وَاصَلَ بِهِمْ يَوْمًا ثُمَّ يَوْمًا ثُمَّ رَأَوُا الْهِلاَلَ فَقَالَ ‏"‏ لَوْ تَأَخَّرَ لَزِدْتُكُمْ ‏"‏‏.‏ كَالْمُنَكِّلِ بِهِمْ حِينَ أَبَوْا‏.‏ تَابَعَهُ شُعَيْبٌ وَيَحْيَى بْنُ سَعِيدٍ وَيُونُسُ عَنِ الزُّهْرِيِّ‏.‏ وَقَالَ عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ عَنِ ابْنِ شِهَابٍ عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6851}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade Al-Wisal (fasting continuously for more than one day without taking any meals). A man from the Muslims said, "But you do Al-Wisal, O Allah's Messenger (ﷺ)!" Allah's Messenger (ﷺ) said, "Who among you is similar to me? I sleep and my Lord makes me eat and drink." When the people refused to give up Al-Wisal, the Prophet (ﷺ) fasted along with them for one day, and did not break his fast but continued his fast for another day, and when they saw the crescent, the Prophet (ﷺ) said, "If the crescent had not appeared, I would have made you continue your fast (for a third day)," as if he wanted to punish them for they had refused to give up Al-Wisal}}
\hadithdefcmd{bukhari}{6852}{حَدَّثَنِي عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُمْ كَانُوا يُضْرَبُونَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا اشْتَرَوْا طَعَامًا جِزَافًا أَنْ يَبِيعُوهُ فِي مَكَانِهِمْ حَتَّى يُئْوُوهُ إِلَى رِحَالِهِمْ‏.‏\hadithno{6852}\hadithtrans{Narrated `Abdullah bin `Umar:Those people who used to buy foodstuff at random (without weighing or measuring it) were beaten in the lifetime of Allah's Messenger (ﷺ) if they sold it at the very place where they had bought it, till they carried it to their dwelling places}}
\hadithdefcmd{bukhari}{6853}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا انْتَقَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَفْسِهِ فِي شَىْءٍ يُؤْتَى إِلَيْهِ حَتَّى تُنْتَهَكَ مِنْ حُرُمَاتِ اللَّهِ فَيَنْتَقِمَ لِلَّهِ‏.‏\hadithno{6853}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) never took revenge for his own self in any matter presented to him till Allah's limits were exceeded, in which case he would take revenge for Allah's sake}}
\hadithdefcmd{bukhari}{6854}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ شَهِدْتُ الْمُتَلاَعِنَيْنِ وَأَنَا ابْنُ خَمْسَ، عَشْرَةَ، فَرَّقَ بَيْنَهُمَا فَقَالَ زَوْجُهَا كَذَبْتُ عَلَيْهَا إِنْ أَمْسَكْتُهَا‏.‏ قَالَ فَحَفِظْتُ ذَاكَ مِنَ الزُّهْرِيِّ ‏ "‏ إِنْ جَاءَتْ بِهِ كَذَا وَكَذَا فَهْوَ، وَإِنْ جَاءَتْ بِهِ كَذَا وَكَذَا كَأَنَّهُ وَحَرَةٌ فَهُوَ ‏"‏‏.‏ وَسَمِعْتُ الزُّهْرِيَّ يَقُولُ جَاءَتْ بِهِ لِلَّذِي يُكْرَهُ\hadithno{6854}\hadithtrans{Narrated Sahl bin Sa`d:I witnessed the case of Lian (the case of a man who charged his wife for committing illegal sexual intercourse when I was fifteen years old. The Prophet (ﷺ) ordered that they be divorced, and the husband said, "If I kept her, I would be a liar." I remember that Az-Zubair also said, "(It was said) that if that woman brought forth the child with such-and-such description, her husband would prove truthful, but if she brought it with such-and-such description looking like a Wahra (a red insect), he would prove untruthful." I heard Az-Zubair also saying, "Finally she gave birth to a child of description which her husband disliked}}
\hadithdefcmd{bukhari}{6855}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ ذَكَرَ ابْنُ عَبَّاسٍ الْمُتَلاَعِنَيْنِ فَقَالَ عَبْدُ اللَّهِ بْنُ شَدَّادٍ هِيَ الَّتِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ رَاجِمًا امْرَأَةً عَنْ غَيْرِ بَيِّنَةٍ ‏"‏‏.‏ قَالَ لاَ، تِلْكَ امْرَأَةٌ أَعْلَنَتْ‏.‏\hadithno{6855}\hadithtrans{Narrated Al-Qasim bin Muhammad:Ibn `Abbas mentioned the couple who had taken the oath of Lian. `Abdullah bin Shaddad said (to him), "Was this woman about whom Allah's Messenger (ﷺ) said, 'If I were ever to stone to death any woman without witnesses. (I would have stoned that woman to death)?' Ibn `Abbas replied," No, that lady exposed herself (by her suspicious behavior)}}
\hadithdefcmd{bukhari}{6856}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ذُكِرَ التَّلاَعُنُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ عَاصِمُ بْنُ عَدِيٍّ فِي ذَلِكَ قَوْلاً، ثُمَّ انْصَرَفَ وَأَتَاهُ رَجُلٌ مِنْ قَوْمِهِ يَشْكُو أَنَّهُ وَجَدَ مَعَ أَهْلِهِ فَقَالَ عَاصِمٌ مَا ابْتُلِيتُ بِهَذَا إِلاَّ لِقَوْلِي فَذَهَبَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ بِالَّذِي وَجَدَ عَلَيْهِ امْرَأَتَهُ، وَكَانَ ذَلِكَ الرَّجُلُ مُصْفَرًّا، قَلِيلَ اللَّحْمِ، سَبِطَ الشَّعَرِ، وَكَانَ الَّذِي ادَّعَى عَلَيْهِ أَنَّهُ وَجَدَهُ عِنْدَ أَهْلِهِ آدَمَ، خَدْلاً، كَثِيرَ اللَّحْمِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَيِّنْ ‏"‏‏.‏ فَوَضَعَتْ شَبِيهًا بِالرَّجُلِ الَّذِي ذَكَرَ زَوْجُهَا أَنَّهُ وَجَدَهُ عِنْدَهَا فَلاَعَنَ النَّبِيُّ صلى الله عليه وسلم بَيْنَهُمَا فَقَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ فِي الْمَجْلِسِ هِيَ الَّتِي قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ رَجَمْتُ أَحَدًا بِغَيْرِ بَيِّنَةٍ رَجَمْتُ هَذِهِ ‏"‏‏.‏ فَقَالَ لاَ، تِلْكَ امْرَأَةٌ كَانَتْ تُظْهِرُ فِي الإِسْلاَمِ السُّوءَ‏.‏\hadithno{6856}\hadithtrans{Narrated Ibn `Abbas:Lian was mentioned in the presence of the Prophet, `Asim bin Adi said a statement about it, and when he left, a man from his tribe came to him complaining that he had seen a man with his wife. `Asim said, "I have been put to trial only because of my statement." So he took the man to the Prophet (ﷺ) and the man told him about the incident. The man (husband) was of yellow complexion, thin, and of lank hair, while the man whom he had accused of having been with his wife, was reddish brown with fat thick legs and fat body. The Prophet (ﷺ) said, "O Allah! Reveal the truth." Later on the lady delivered a child resembling the man whom the husband had accused of having been with her. So the Prophet (ﷺ) made them take the oath of Lian. A man said to Ibn `Abbas in the gathering, "Was that the same lady about whom the Prophet (ﷺ) said, "If I were to stone any lady (for committing illegal sexual intercourse) to death without witnesses, I would have stoned that lade to death?" Ibn `Abbas said, "No, that was another lady who used to behave in such a suspicious way among the Muslims that one might accuse her of committing illegal sexual intercourse}}
\hadithdefcmd{bukhari}{6857}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ اجْتَنِبُوا السَّبْعَ الْمُوبِقَاتِ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا هُنَّ قَالَ ‏"‏ الشِّرْكُ بِاللَّهِ، وَالسِّحْرُ، وَقَتْلُ النَّفْسِ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ، وَأَكْلُ الرِّبَا، وَأَكْلُ مَالِ الْيَتِيمِ، وَالتَّوَلِّي يَوْمَ الزَّحْفِ، وَقَذْفُ الْمُحْصَنَاتِ الْمُؤْمِنَاتِ الْغَافِلاَتِ ‏"‏‏.‏\hadithno{6857}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Avoid the seven great destructive sins." They (the people!) asked, "O Allah's Apostle! What are they?" He said, "To join partners in worship with Allah; to practice sorcery; to kill the life which Allah has forbidden except for a just cause (according to Islamic law); to eat up usury (Riba), to eat up the property of an orphan; to give one's back to the enemy and fleeing from the battle-field at the time of fighting and to accuse chaste women who never even think of anything touching chastity and are good believers}}
\hadithdefcmd{bukhari}{6858}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ فُضَيْلِ بْنِ غَزْوَانَ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ أَبَا الْقَاسِمِ، صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَذَفَ مَمْلُوكَهُ وَهْوَ بَرِيءٌ مِمَّا قَالَ، جُلِدَ يَوْمَ الْقِيَامَةِ، إِلاَّ أَنْ يَكُونَ كَمَا قَالَ ‏"‏‏.‏\hadithno{6858}\hadithtrans{Narrated Abu Huraira:I heard Abu-l-Qasim (the Prophet) saying, "If somebody slanders his slave and the slave is free from what he says, he will be flogged on the Day of Resurrection unless the slave is really as he has described him}}
\hadithdefcmd{bukhari}{6860}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالاَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَنْشُدُكَ اللَّهَ إِلاَّ قَضَيْتَ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ وَكَانَ أَفْقَهَ مِنْهُ فَقَالَ صَدَقَ، اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ، وَأْذَنْ لِي يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قُلْ ‏"‏‏.‏ فَقَالَ إِنَّ ابْنِي كَانَ عَسِيفًا فِي أَهْلِ، هَذَا فَزَنَى بِامْرَأَتِهِ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَخَادِمٍ وَإِنِّي سَأَلْتُ رِجَالاً مِنْ أَهْلِ الْعِلْمِ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي جَلْدَ مِائَةٍ وَتَغْرِيبَ عَامٍ، وَأَنَّ عَلَى امْرَأَةِ هَذَا الرَّجْمَ‏.‏ فَقَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، الْمِائَةُ وَالْخَادِمُ رَدٌّ عَلَيْكَ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَيَا أُنَيْسُ اغْدُ عَلَى امْرَأَةِ هَذَا فَسَلْهَا، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏ فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏\hadithno{6860}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid Al-Juhani:A man came to the Prophet (ﷺ) and said, "I beseech you to judge us according to Allah's Laws." Then his opponent who was wiser than he, got up and said, "He has spoken the truth. So judge us according to Allah's Laws and please allow me (to speak), O Allah's Messenger (ﷺ)." The Prophet (ﷺ) said, "Speak." He said, "My son was a laborer for the family of this man and he committed illegal sexual intercourse with his wife, and I gave one-hundred sheep and a slave as a ransom (for my son), but I asked the religious learned people (regarding this case), and they informed me that my son should be flogged onehundred stripes, and be exiled for one year, and the wife of this man should be stoned (to death)."The Prophet (ﷺ) said, "By Him in Whose Hand my soul is, I will Judge you (in this case) according to Allah's Laws. The one-hundred (sheep) and the slave shall be returned to you and your son shall be flogged one-hundred stripes and be exiled for one year. And O Unais! Go in the morning to the wife of this man and ask her, and if she confesses, stone her to death." She confessed and he stoned her to death}}
